<?php
// Iniciar buffer de salida al principio
ob_start();

// Configuración de errores (solo para desarrollo)
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);

// Inicio seguro de sesión
if (session_status() !== PHP_SESSION_ACTIVE) {
    session_start();
}

// Verificación de autenticación
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    ob_end_flush();
    exit;
}

// Conexión a base de datos
require_once '../config/database.php';

// Procesar actualización de estado de pago
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['actualizar_pago'])) {
    try {
        $participante_id = (int)$_POST['participante_id'];
        $valor = isset($_POST['valor']) ? (float)$_POST['valor'] : null;
        $fecha_pago = isset($_POST['fecha_pago']) ? $_POST['fecha_pago'] : null;
        $corresponsal = isset($_POST['corresponsal']) ? $_POST['corresponsal'] : null;
        $cuenta = isset($_POST['cuenta']) ? $_POST['cuenta'] : null;
        $observaciones = isset($_POST['observaciones']) ? $_POST['observaciones'] : null;
        $procesado = isset($_POST['procesado']) ? 1 : 0;

        // Actualizar en la base de datos
        $stmt = $pdo->prepare("
            UPDATE inscripciones 
            SET valor_pago = ?, 
                fecha_pago = ?, 
                corresponsal_pago = ?, 
                cuenta_pago = ?, 
                observaciones_pago = ?, 
                procesado_pago = ?,
                fecha_procesado = NOW()
            WHERE participante_id = ?
        ");
        
        $stmt->execute([
            $valor,
            $fecha_pago,
            $corresponsal,
            $cuenta,
            $observaciones,
            $procesado,
            $participante_id
        ]);

        $_SESSION['flash_message'] = [
            'type' => 'success',
            'message' => 'Información de pago actualizada correctamente.'
        ];
        
        header("Location: conciliaciones.php");
        ob_end_flush();
        exit;
        
    } catch (Exception $e) {
        $_SESSION['flash_message'] = [
            'type' => 'danger',
            'message' => 'Error al actualizar: ' . $e->getMessage()
        ];
    }
}

// Obtener todos los inscritos con información de cursos y pagos
try {
    $stmt = $pdo->prepare("
        SELECT 
            p.id,
            p.nombres,
            p.apellidos,
            p.cedula,
            p.correo,
            p.celular,
            CONCAT('CB ', p.clase_cuerpo_bomberos, ' ', p.municipio) as institucion,
            p.direccion,
            p.archivo_rut,
            c.nombre as curso_nombre,
            i.fecha_inscripcion,
            i.valor_pago,
            i.fecha_pago,
            i.corresponsal_pago,
            i.cuenta_pago,
            i.observaciones_pago,
            i.procesado_pago
        FROM 
            participantes p
        INNER JOIN 
            inscripciones i ON p.id = i.participante_id
        INNER JOIN 
            cursos c ON i.curso_id = c.id
        ORDER BY 
            i.procesado_pago ASC, 
            i.fecha_inscripcion DESC
    ");
    $stmt->execute();
    $inscritos = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
} catch (Exception $e) {
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'Error al obtener los inscritos: ' . $e->getMessage()
    ];
    $inscritos = [];
}

// Función para obtener la ruta del RUT
function getRutPath($participante) {
    if (empty($participante['archivo_rut'])) {
        return false;
    }
    
    if (filter_var($participante['archivo_rut'], FILTER_VALIDATE_URL)) {
        return $participante['archivo_rut'];
    }
    
    $base_path = '../documentos/';
    $participante_folder = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $participante['nombres'] . '_' . $participante['apellidos'])) . '_' . $participante['cedula'];
    
    $rutas_posibles = [
        $base_path . $participante_folder . '/' . $participante['archivo_rut'],
        $base_path . $participante['archivo_rut'],
        '../' . $participante['archivo_rut']
    ];
    
    foreach ($rutas_posibles as $ruta) {
        if (file_exists($ruta) {
            return $ruta;
        }
    }
    
    return false;
}

// Limpiar buffer antes de enviar HTML
ob_clean();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Conciliaciones Bancarias | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- IonIcons -->
    <link rel="stylesheet" href="https://code.ionicframework.com/ionicons/2.0.1/css/ionicons.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <!-- DataTables -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.5/css/dataTables.bootstrap4.min.css">
    <!-- Tempusdominus Bootstrap 4 -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/5.39.0/css/tempusdominus-bootstrap-4.min.css">
    
    <style>
        .table-responsive {
            overflow-x: auto;
        }
        .rut-container {
            max-width: 200px;
            max-height: 100px;
            overflow: hidden;
        }
        .rut-container img {
            width: 100%;
            height: auto;
            cursor: pointer;
        }
        .procesado-true {
            background-color: #d4edda !important;
        }
        .procesado-false {
            background-color: #fff3cd !important;
        }
        .modal-rut-container {
            max-height: 80vh;
            overflow: auto;
        }
        .modal-rut-container img {
            width: 100%;
            height: auto;
        }
    </style>
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Left navbar links -->
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#" role="button"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="dashboard.php" class="nav-link">Inicio</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="ver_cursos.php" class="nav-link">Cursos</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="conciliaciones.php" class="nav-link active">Conciliaciones</a>
            </li>
        </ul>
    </nav>
    <!-- /.navbar -->

    <!-- Main Sidebar Container -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <!-- Brand Logo -->
        <a href="dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>

        <!-- Sidebar -->
        <div class="sidebar">
            <!-- Sidebar user panel (optional) -->
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" 
                          style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?= strtoupper(substr($_SESSION['admin_nombre'], 0, 1)) ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?= htmlspecialchars($_SESSION['admin_nombre']) ?></a>
                </div>
            </div>

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                    <li class="nav-item">
                        <a href="dashboard.php" class="nav-link">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="crear_curso.php" class="nav-link">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_cursos.php" class="nav-link">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="inscribir_participante.php" class="nav-link">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_inscritos.php" class="nav-link">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="conciliaciones.php" class="nav-link active">
                            <i class="nav-icon fas fa-money-bill-wave"></i>
                            <p>Conciliaciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="logout.php" class="nav-link text-danger">
                            <i class="nav-icon fas fa-sign-out-alt"></i>
                            <p>Cerrar Sesión</p>
                        </a>
                    </li>
                </ul>
            </nav>
            <!-- /.sidebar-menu -->
        </div>
        <!-- /.sidebar -->
    </aside>

    <!-- Content Wrapper. Contains page content -->
    <div class="content-wrapper">
        <!-- Content Header (Page header) -->
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Conciliaciones Bancarias</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="dashboard.php">Inicio</a></li>
                            <li class="breadcrumb-item active">Conciliaciones</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-12">
                        <div class="card">
                            <div class="card-header">
                                <h3 class="card-title">Registro de Pagos de Inscritos</h3>
                                <div class="card-tools">
                                    <div class="input-group input-group-sm">
                                        <div class="btn-group">
                                            <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
                                                Filtros
                                            </button>
                                            <div class="dropdown-menu">
                                                <a class="dropdown-item" href="?filtro=todos">Todos</a>
                                                <a class="dropdown-item" href="?filtro=procesados">Procesados</a>
                                                <a class="dropdown-item" href="?filtro=no_procesados">No Procesados</a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- /.card-header -->
                            <div class="card-body">
                                <?php if (isset($_SESSION['flash_message'])): ?>
                                    <div class="alert alert-<?= $_SESSION['flash_message']['type'] ?>">
                                        <?= $_SESSION['flash_message']['message'] ?>
                                    </div>
                                    <?php unset($_SESSION['flash_message']); ?>
                                <?php endif; ?>
                                
                                <?php if (empty($inscritos)): ?>
                                    <div class="alert alert-info">No hay inscritos registrados.</div>
                                <?php else: ?>
                                    <div class="table-responsive">
                                        <table id="conciliacionesTable" class="table table-bordered table-striped">
                                            <thead>
                                                <tr>
                                                    <th>Nombre Completo</th>
                                                    <th>Cédula/NIT</th>
                                                    <th>E-mail</th>
                                                    <th>Teléfono</th>
                                                    <th>Institución</th>
                                                    <th>Dirección</th>
                                                    <th>Curso</th>
                                                    <th>RUT</th>
                                                    <th>Valor</th>
                                                    <th>Fecha Pago</th>
                                                    <th>Corresponsal</th>
                                                    <th>Cuenta</th>
                                                    <th>Observaciones</th>
                                                    <th>Estado</th>
                                                    <th>Acciones</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($inscritos as $inscrito): 
                                                    $rut_path = getRutPath($inscrito);
                                                    $procesado_class = $inscrito['procesado_pago'] ? 'procesado-true' : 'procesado-false';
                                                ?>
                                                    <tr class="<?= $procesado_class ?>">
                                                        <td><?= htmlspecialchars(mb_strtoupper($inscrito['nombres'] . ' ' . $inscrito['apellidos'])) ?></td>
                                                        <td><?= htmlspecialchars($inscrito['cedula']) ?></td>
                                                        <td><?= htmlspecialchars(strtolower($inscrito['correo'])) ?></td>
                                                        <td><?= htmlspecialchars($inscrito['celular']) ?></td>
                                                        <td><?= htmlspecialchars($inscrito['institucion']) ?></td>
                                                        <td><?= htmlspecialchars($inscrito['direccion']) ?></td>
                                                        <td><?= htmlspecialchars($inscrito['curso_nombre']) ?></td>
                                                        <td>
                                                            <?php if ($rut_path): ?>
                                                                <div class="rut-container" data-toggle="modal" data-target="#rutModal" data-rut="<?= htmlspecialchars($rut_path) ?>">
                                                                    <img src="<?= htmlspecialchars($rut_path) ?>" alt="RUT">
                                                                </div>
                                                            <?php else: ?>
                                                                <span class="text-muted">No disponible</span>
                                                            <?php endif; ?>
                                                        </td>
                                                        <td><?= $inscrito['valor_pago'] ? '$ ' . number_format($inscrito['valor_pago'], 2, ',', '.') : '-' ?></td>
                                                        <td><?= $inscrito['fecha_pago'] ? date('d/m/Y', strtotime($inscrito['fecha_pago'])) : '-' ?></td>
                                                        <td><?= $inscrito['corresponsal_pago'] ? htmlspecialchars($inscrito['corresponsal_pago']) : '-' ?></td>
                                                        <td><?= $inscrito['cuenta_pago'] ? htmlspecialchars($inscrito['cuenta_pago']) : '-' ?></td>
                                                        <td><?= $inscrito['observaciones_pago'] ? htmlspecialchars($inscrito['observaciones_pago']) : '-' ?></td>
                                                        <td>
                                                            <?php if ($inscrito['procesado_pago']): ?>
                                                                <span class="badge badge-success">Procesado</span>
                                                            <?php else: ?>
                                                                <span class="badge badge-warning">Pendiente</span>
                                                            <?php endif; ?>
                                                        </td>
                                                        <td>
                                                            <button class="btn btn-sm btn-primary editar-pago" 
                                                                    data-id="<?= $inscrito['id'] ?>"
                                                                    data-valor="<?= $inscrito['valor_pago'] ?>"
                                                                    data-fecha="<?= $inscrito['fecha_pago'] ?>"
                                                                    data-corresponsal="<?= htmlspecialchars($inscrito['corresponsal_pago']) ?>"
                                                                    data-cuenta="<?= htmlspecialchars($inscrito['cuenta_pago']) ?>"
                                                                    data-observaciones="<?= htmlspecialchars($inscrito['observaciones_pago']) ?>"
                                                                    data-procesado="<?= $inscrito['procesado_pago'] ?>">
                                                                <i class="fas fa-edit"></i> Editar
                                                            </button>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                <?php endif; ?>
                            </div>
                            <!-- /.card-body -->
                        </div>
                        <!-- /.card -->
                    </div>
                    <!-- /.col -->
                </div>
                <!-- /.row -->
            </div><!-- /.container-fluid -->
        </section>
        <!-- /.content -->
    </div>
    <!-- /.content-wrapper -->

    <!-- Modal para ver RUT -->
    <div class="modal fade" id="rutModal" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog modal-lg" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">RUT del Participante</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <div class="modal-rut-container">
                        <img id="rutImagen" src="" class="img-fluid" alt="RUT del participante">
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">Cerrar</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal para editar pago -->
    <div class="modal fade" id="editarPagoModal" tabindex="-1" role="dialog" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <form method="POST" action="">
                    <div class="modal-header">
                        <h5 class="modal-title">Editar Información de Pago</h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <input type="hidden" name="participante_id" id="participante_id">
                        <input type="hidden" name="actualizar_pago" value="1">
                        
                        <div class="form-group">
                            <label for="valor">Valor</label>
                            <input type="number" class="form-control" id="valor" name="valor" step="0.01" min="0">
                        </div>
                        
                        <div class="form-group">
                            <label for="fecha_pago">Fecha de Pago</label>
                            <div class="input-group date" id="fecha_pago" data-target-input="nearest">
                                <input type="text" class="form-control datetimepicker-input" 
                                       name="fecha_pago" data-target="#fecha_pago"/>
                                <div class="input-group-append" data-target="#fecha_pago" data-toggle="datetimepicker">
                                    <div class="input-group-text"><i class="fa fa-calendar"></i></div>
                                </div>
                            </div>
                        </div>
                        
                        <div class="form-group">
                            <label for="corresponsal">Corresponsal</label>
                            <input type="text" class="form-control" id="corresponsal" name="corresponsal">
                        </div>
                        
                        <div class="form-group">
                            <label for="cuenta">Cuenta</label>
                            <input type="text" class="form-control" id="cuenta" name="cuenta">
                        </div>
                        
                        <div class="form-group">
                            <label for="observaciones">Observaciones</label>
                            <textarea class="form-control" id="observaciones" name="observaciones" rows="3"></textarea>
                        </div>
                        
                        <div class="form-group form-check">
                            <input type="checkbox" class="form-check-input" id="procesado" name="procesado">
                            <label class="form-check-label" for="procesado">Marcar como procesado</label>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">Cancelar</button>
                        <button type="submit" class="btn btn-primary">Guardar Cambios</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- REQUIRED SCRIPTS -->
    <!-- jQuery -->
    <script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
    <!-- Bootstrap 4 -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
    <!-- AdminLTE App -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
    <!-- DataTables -->
    <script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.5/js/dataTables.bootstrap4.min.js"></script>
    <!-- Moment -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/moment.js/2.29.1/moment.min.js"></script>
    <!-- Tempusdominus Bootstrap 4 -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/tempusdominus-bootstrap-4/5.39.0/js/tempusdominus-bootstrap-4.min.js"></script>

    <script>
        $(function () {
            // Inicializar DataTable
            $('#conciliacionesTable').DataTable({
                "responsive": true,
                "autoWidth": false,
                "language": {
                    "lengthMenu": "Mostrar _MENU_ registros por página",
                    "zeroRecords": "No se encontraron resultados",
                    "info": "Mostrando página _PAGE_ de _PAGES_",
                    "infoEmpty": "No hay registros disponibles",
                    "infoFiltered": "(filtrado de _MAX_ registros totales)",
                    "search": "Buscar:",
                    "paginate": {
                        "first": "Primero",
                        "last": "Último",
                        "next": "Siguiente",
                        "previous": "Anterior"
                    }
                }
            });

            // Mostrar RUT en modal
            $('#rutModal').on('show.bs.modal', function (event) {
                var button = $(event.relatedTarget);
                var rutSrc = button.data('rut');
                var modal = $(this);
                modal.find('#rutImagen').attr('src', rutSrc);
            });

            // Configurar datetimepicker
            $('#fecha_pago').datetimepicker({
                format: 'YYYY-MM-DD',
                locale: 'es'
            });

            // Manejar clic en botón editar pago
            $('.editar-pago').click(function() {
                var id = $(this).data('id');
                var valor = $(this).data('valor');
                var fecha = $(this).data('fecha');
                var corresponsal = $(this).data('corresponsal');
                var cuenta = $(this).data('cuenta');
                var observaciones = $(this).data('observaciones');
                var procesado = $(this).data('procesado');
                
                $('#participante_id').val(id);
                $('#valor').val(valor);
                $('#fecha_pago').datetimepicker('date', fecha ? moment(fecha) : null);
                $('#corresponsal').val(corresponsal);
                $('#cuenta').val(cuenta);
                $('#observaciones').val(observaciones);
                $('#procesado').prop('checked', procesado);
                
                $('#editarPagoModal').modal('show');
            });
        });
    </script>
</body>
</html>
<?php
// Finalizar buffer de salida
ob_end_flush();
?>