<?php
session_start();

// Verificación de sesión
if (!isset($_SESSION['admin_id']) || !isset($_SESSION['admin_nombre'])) {
    header("Location: login.php");
    exit;
}

// Verificar PDO
if (!extension_loaded('pdo')) {
    die('<div style="padding:20px;font-family:Arial;color:#fff;background:#dc3545;">
        <h2>Error de Configuración</h2>
        <p>La extensión PDO no está habilitada en tu servidor PHP.</p>
    </div>');
}

// Configuración de conexión
$host = 'localhost';
$dbname = 'wwesib_inscripciones_esiboc';
$username = 'wwesib_esiboc_inscripciones';
$password = '^YV#E0ZC1CG]';

try {
    $pdo = new PDO("mysql:host=$host;dbname=$dbname;charset=utf8", $username, $password);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
    $pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);

    // Consulta optimizada para actividades recientes
    $queryActividad = "SELECT * FROM (
        (
            -- Inscripciones nuevas
            SELECT 
                'inscripcion' as tipo,
                CONCAT(p.nombres, ' ', p.apellidos) as nombre,
                c.nombre as detalle,
                i.fecha_inscripcion as fecha,
                'Nueva inscripción' as accion,
                'success' as badge_color,
                'fa-user-plus' as icono,
                1 as prioridad
            FROM inscripciones i
            JOIN participantes p ON i.participante_id = p.id
            JOIN cursos c ON i.curso_id = c.id
            ORDER BY i.fecha_inscripcion DESC
            LIMIT 100
        )
        UNION ALL
        (
            -- Cursos nuevos
            SELECT 
                'curso' as tipo,
                c.nombre as nombre,
                CONCAT('Estado: ', c.estado) as detalle,
                c.creado_en as fecha,
                'Curso creado' as accion,
                'info' as badge_color,
                'fa-book' as icono,
                1 as prioridad
            FROM cursos c
            ORDER BY c.creado_en DESC
            LIMIT 100
        )
        UNION ALL
        (
            -- Cursos habilitados/deshabilitados
            SELECT 
                'curso' as tipo,
                c.nombre as nombre,
                CASE 
                    WHEN c.habilitado = 1 THEN 'HABILITADO'
                    ELSE 'DESHABILITADO'
                END as detalle,
                c.fecha_actualizacion as fecha,
                CASE 
                    WHEN c.habilitado = 1 THEN 'Curso habilitado'
                    ELSE 'Curso deshabilitado'
                END as accion,
                CASE 
                    WHEN c.habilitado = 1 THEN 'success' 
                    ELSE 'danger'
                END as badge_color,
                CASE 
                    WHEN c.habilitado = 1 THEN 'fa-toggle-on' 
                    ELSE 'fa-toggle-off'
                END as icono,
                1 as prioridad
            FROM cursos c
            WHERE c.fecha_actualizacion != c.fecha_creacion
            ORDER BY c.fecha_actualizacion DESC
            LIMIT 100
        )
        UNION ALL
        (
            -- Ediciones de participantes
            SELECT 
                'participante' as tipo,
                CONCAT(p.nombres, ' ', p.apellidos) as nombre,
                'Datos actualizados' as detalle,
                p.fecha_actualizacion as fecha,
                'Participante editado' as accion,
                'warning' as badge_color,
                'fa-user-edit' as icono,
                2 as prioridad
            FROM participantes p
            WHERE p.fecha_actualizacion != p.creado_en
            ORDER BY p.fecha_actualizacion DESC
            LIMIT 100
        )
        UNION ALL
        (
            -- Otras modificaciones de cursos
            SELECT 
                'curso' as tipo,
                c.nombre as nombre,
                CONCAT('Modificado: ', 
                    GROUP_CONCAT(
                        DISTINCT 
                        CASE 
                            WHEN h.campo = 'nombre' THEN 'nombre'
                            WHEN h.campo = 'descripcion' THEN 'descripción'
                            WHEN h.campo = 'fecha_inicio' THEN 'fecha inicio'
                            ELSE h.campo
                        END
                        SEPARATOR ', '
                    )
                ) as detalle,
                MAX(h.fecha_cambio) as fecha,
                'Actualización de curso' as accion,
                'info' as badge_color,
                'fa-edit' as icono,
                2 as prioridad
            FROM cursos c
            JOIN cursos_historial h ON c.id = h.curso_id
            WHERE h.campo != 'habilitado'
            GROUP BY c.id
            ORDER BY MAX(h.fecha_cambio) DESC
            LIMIT 100
        )
    ) AS actividades_completas
    ORDER BY prioridad ASC, fecha DESC
    LIMIT 200";

    $stmt = $pdo->query($queryActividad);
    $stats['actividad_reciente'] = $stmt->fetchAll();
    $totalActividades = count($stats['actividad_reciente']);

    // Obtener estadísticas básicas
    $stats['cursos_activos'] = $pdo->query("SELECT COUNT(*) FROM cursos WHERE estado = 'activo'")->fetchColumn();
    $stats['total_participantes'] = $pdo->query("SELECT COUNT(*) FROM participantes")->fetchColumn();
    $stats['inscripciones_recientes'] = $pdo->query("SELECT COUNT(*) FROM inscripciones WHERE fecha_inscripcion >= DATE_SUB(NOW(), INTERVAL 7 DAY)")->fetchColumn();
    $stats['proximos_cursos'] = $pdo->query("SELECT COUNT(*) FROM cursos WHERE fecha_inicio BETWEEN NOW() AND DATE_ADD(NOW(), INTERVAL 30 DAY)")->fetchColumn();

    // Cursos por llenarse (70-99% de capacidad)
    $stats['cursos_por_llenarse'] = $pdo->query("
        SELECT 
            c.id,
            c.nombre,
            c.cupo_maximo,
            COUNT(i.id) as inscritos,
            ROUND((COUNT(i.id)/c.cupo_maximo)*100) as porcentaje
        FROM cursos c
        LEFT JOIN inscripciones i ON c.id = i.curso_id
        WHERE c.fecha_inicio > CURDATE()
        GROUP BY c.id
        HAVING porcentaje >= 70 AND porcentaje < 100
        ORDER BY porcentaje DESC
        LIMIT 3
    ")->fetchAll();

    // Eventos para calendario
    $eventosCalendario = $pdo->query("
        SELECT id, nombre, fecha_inicio as start, fecha_fin as end, 
        CASE 
            WHEN fecha_inicio > CURDATE() THEN 'bg-info'
            WHEN fecha_fin < CURDATE() THEN 'bg-secondary'
            ELSE 'bg-success'
        END as className
        FROM cursos
        WHERE fecha_inicio <= DATE_ADD(NOW(), INTERVAL 6 MONTH)
        AND fecha_fin >= DATE_SUB(NOW(), INTERVAL 1 MONTH)
    ")->fetchAll();
    $eventosJson = json_encode($eventosCalendario);

} catch(PDOException $e) {
    die('<div style="padding:20px;font-family:Arial;color:#fff;background:#dc3545;">
        <h2>Error de Base de Datos</h2>
        <p>' . htmlspecialchars($e->getMessage()) . '</p>
    </div>');
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Dashboard Admin | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <!-- FullCalendar CSS -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/fullcalendar@5.11.3/main.min.css">
    <style>
        /* Estilos para fijar el sidebar */
        .wrapper {
            overflow: hidden;
        }

        .main-sidebar {
            position: fixed;
            height: 100vh;
            overflow-y: auto;
        }

        .content-wrapper {
            margin-left: 250px;
            overflow-y: auto;
            height: calc(100vh - 57px);
            margin-top: 57px;
        }

        .main-header {
            position: fixed;
            width: 100%;
            z-index: 1030;
            margin-left: 250px;
            top: 0;
        }

        .main-footer {
            margin-left: 250px;
        }

        /* Ajustes para pantallas pequeñas */
        @media (max-width: 767px) {
            .content-wrapper,
            .main-header,
            .main-footer {
                margin-left: 0;
            }
            
            .main-sidebar {
                position: fixed;
                z-index: 1031;
                height: 100vh;
                transform: translateX(-100%);
            }
            
            .sidebar-collapse .main-sidebar {
                transform: translateX(0);
            }
        }

        .activity-scroll {
            max-height: 500px;
            overflow-y: auto;
            padding-right: 10px;
        }
        .activity-item {
            border-bottom: 1px solid #f4f4f4;
            padding: 10px 0;
        }
        .small-box {
            cursor: pointer;
            transition: transform 0.3s;
        }
        .small-box:hover {
            transform: translateY(-5px);
        }
        #calendar {
            font-size: 0.85em;
        }
        @media (max-width: 767px) {
            #calendar {
                font-size: 0.75em;
            }
        }
    </style>
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="dashboard.php" class="nav-link">Inicio</a>
            </li>
        </ul>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
               <a class="nav-link" href="logout.php" onclick="return confirmarCerrarSesion();">
    <i class="fas fa-sign-out-alt"></i> Cerrar Sesión
</a>

            </li>
        </ul>
    </nav>

    <!-- Sidebar -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <a href="dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>
        <div class="sidebar">
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?= strtoupper(substr($_SESSION['admin_nombre'], 0, 1)) ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?= htmlspecialchars($_SESSION['admin_nombre']) ?></a>
                </div>
            </div>
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column">
                    <li class="nav-item">
                        <a href="dashboard.php" class="nav-link active">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="crear_curso.php" class="nav-link">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_cursos.php" class="nav-link">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="inscribir_participante.php" class="nav-link">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_inscritos.php" class="nav-link">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
            <a href="conciliaciones.php" class="nav-link">
                <i class="nav-icon fas fa-money-bill-wave"></i>
                <p>Conciliaciones</p>
            </a>
        </li>
                    
                    <li class="nav-item">
                        <a href="logout.php" class="nav-link text-danger">
                            <i class="nav-icon fas fa-sign-out-alt"></i>
                            <p>Cerrar Sesión</p>
                        </a>
                    </li>
                </ul>
            </nav>
        </div>
    </aside>

    <!-- Content Wrapper -->
    <div class="content-wrapper">
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Panel de Administración</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="#">Inicio</a></li>
                            <li class="breadcrumb-item active">Dashboard</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <!-- Small boxes -->
                <div class="row">
                    <div class="col-lg-3 col-6">
                        <div class="small-box bg-info" onclick="window.location.href='ver_cursos.php'">
                            <div class="inner">
                                <h3><?= $stats['cursos_activos'] ?></h3>
                                <p>Cursos Activos</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-book-open"></i>
                            </div>
                            <a href="ver_cursos.php" class="small-box-footer">Más info <i class="fas fa-arrow-circle-right"></i></a>
                        </div>
                    </div>
                    <div class="col-lg-3 col-6">
                        <div class="small-box bg-success" onclick="window.location.href='ver_inscritos.php'">
                            <div class="inner">
                                <h3><?= $stats['total_participantes'] ?></h3>
                                <p>Participantes</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-users"></i>
                            </div>
                            <a href="ver_inscritos.php" class="small-box-footer">Más info <i class="fas fa-arrow-circle-right"></i></a>
                        </div>
                    </div>
                    <div class="col-lg-3 col-6">
                        <div class="small-box bg-warning">
                            <div class="inner">
                                <h3><?= $stats['inscripciones_recientes'] ?></h3>
                                <p>Inscripciones (7 días)</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-chart-line"></i>
                            </div>
                            <a href="#" class="small-box-footer">Más info <i class="fas fa-arrow-circle-right"></i></a>
                        </div>
                    </div>
                    <div class="col-lg-3 col-6">
                        <div class="small-box bg-danger" onclick="window.location.href='ver_cursos.php?filter=proximos'">
                            <div class="inner">
                                <h3><?= $stats['proximos_cursos'] ?></h3>
                                <p>Próximos Cursos</p>
                            </div>
                            <div class="icon">
                                <i class="fas fa-calendar-check"></i>
                            </div>
                            <a href="ver_cursos.php?filter=proximos" class="small-box-footer">Más info <i class="fas fa-arrow-circle-right"></i></a>
                        </div>
                    </div>
                </div>

                <!-- Main row -->
                <div class="row">
                    <!-- Left col -->
                    <section class="col-lg-7 connectedSortable">
                        <!-- Actividad Reciente -->
                        <div class="card">
                            <div class="card-header">
                                <h3 class="card-title">
                                    <i class="fas fa-history mr-1"></i>
                                    Actividad Reciente
                                </h3>
                                <div class="card-tools">
                                    <span class="badge badge-primary">Total: <?= $totalActividades ?></span>
                                </div>
                            </div>
                            <div class="card-body">
                                <div class="activity-scroll">
                                    <?php if (!empty($stats['actividad_reciente'])): ?>
                                        <?php foreach ($stats['actividad_reciente'] as $act): ?>
                                            <div class="activity-item">
                                                <span class="badge badge-<?= $act['badge_color'] ?>">
                                                    <?= strtoupper($act['accion']) ?>
                                                </span>
                                                <p class="mb-1">
                                                    <i class="fas <?= $act['icono'] ?> mr-1"></i>
                                                    <?php if ($act['tipo'] == 'inscripcion'): ?>
                                                        <strong><?= htmlspecialchars($act['nombre']) ?></strong> 
                                                        se inscribió en <strong><?= htmlspecialchars($act['detalle']) ?></strong>
                                                    <?php elseif ($act['tipo'] == 'curso'): ?>
                                                        <?php if (strpos($act['accion'], 'habilitado') !== false): ?>
                                                            Curso <strong><?= htmlspecialchars($act['nombre']) ?></strong> 
                                                            fue <strong><?= strtolower($act['accion']) ?></strong>
                                                        <?php else: ?>
                                                            Curso <strong><?= htmlspecialchars($act['nombre']) ?></strong> 
                                                            (<?= htmlspecialchars($act['detalle']) ?>)
                                                        <?php endif; ?>
                                                    <?php elseif ($act['tipo'] == 'participante'): ?>
                                                        <strong><?= htmlspecialchars($act['nombre']) ?></strong> 
                                                        fue editado
                                                    <?php endif; ?>
                                                </p>
                                                <span class="time"><i class="far fa-clock"></i> <?= date('d/m/Y H:i', strtotime($act['fecha'])) ?></span>
                                            </div>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <p class="text-muted">No hay actividad reciente para mostrar.</p>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        
                        <!-- Cursos por Llenarse -->
                        <div class="card">
                            <div class="card-header">
                                <h3 class="card-title">
                                    <i class="fas fa-exclamation-triangle mr-1"></i>
                                    Cursos por Llenarse
                                </h3>
                                <div class="card-tools">
                                    <span class="badge badge-warning">Alerta</span>
                                </div>
                            </div>
                            <div class="card-body">
                                <?php if (!empty($stats['cursos_por_llenarse'])): ?>
                                    <?php foreach ($stats['cursos_por_llenarse'] as $curso): ?>
                                        <div class="mb-3">
                                            <h5 class="mb-1"><?= htmlspecialchars($curso['nombre']) ?></h5>
                                            <div class="progress progress-sm">
                                                <div class="progress-bar bg-warning" style="width: <?= $curso['porcentaje'] ?>%"></div>
                                            </div>
                                            <small class="text-muted">
                                                <?= $curso['inscritos'] ?> / <?= $curso['cupo_maximo'] ?> inscritos 
                                                (<?= $curso['porcentaje'] ?>%)
                                            </small>
                                            <a href="ver_cursos.php?id=<?= $curso['id'] ?>" class="btn btn-xs btn-default float-right">
                                                Ver detalles
                                            </a>
                                        </div>
                                    <?php endforeach; ?>
                                <?php else: ?>
                                    <p class="text-muted">No hay cursos próximos a llenarse.</p>
                                <?php endif; ?>
                            </div>
                        </div>
                    </section>
                    
                    <!-- right col -->
                    <section class="col-lg-5 connectedSortable">
                        <!-- Calendar -->
                        <div class="card">
                            <div class="card-header border-0">
                                <h3 class="card-title">
                                    <i class="far fa-calendar-alt mr-2"></i>
                                    Calendario de Cursos
                                </h3>
                                <div class="card-tools">
                                    <button type="button" class="btn btn-tool" data-card-widget="collapse">
                                        <i class="fas fa-minus"></i>
                                    </button>
                                </div>
                            </div>
                            <div class="card-body pt-0 pb-2">
                                <div id="calendar" style="min-height: 250px;"></div>
                            </div>
                            <div class="card-footer p-2">
                                <div class="row text-center">
                                    <div class="col-4">
                                        <span class="badge bg-info mr-1"></span>
                                        <small>Próximos</small>
                                    </div>
                                    <div class="col-4">
                                        <span class="badge bg-success mr-1"></span>
                                        <small>En curso</small>
                                    </div>
                                    <div class="col-4">
                                        <span class="badge bg-secondary mr-1"></span>
                                        <small>Finalizados</small>
                                    </div>
                                </div>
                            </div>
                        </div>
                        
                        <!-- Últimos Cursos Creados -->
                        <div class="card">
                            <div class="card-header">
                                <h3 class="card-title">
                                    <i class="fas fa-book mr-1"></i>
                                    Últimos Cursos
                                </h3>
                                <div class="card-tools">
                                    <a href="crear_curso.php" class="btn btn-tool">
                                        <i class="fas fa-plus"></i>
                                    </a>
                                </div>
                            </div>
                            <div class="card-body p-0">
                                <ul class="products-list product-list-in-card pl-2 pr-2">
                                    <?php 
                                    $ultimosCursos = $pdo->query("SELECT id, nombre, fecha_inicio, estado FROM cursos ORDER BY creado_en DESC LIMIT 4")->fetchAll();
                                    ?>
                                    <?php foreach ($ultimosCursos as $curso): ?>
                                        <li class="item">
                                            <div class="product-img">
                                                <i class="fas fa-book fa-2x text-primary"></i>
                                            </div>
                                            <div class="product-info">
                                                <a href="ver_cursos.php?id=<?= $curso['id'] ?>" class="product-title">
                                                    <?= htmlspecialchars($curso['nombre']) ?>
                                                    <span class="badge badge-<?= $curso['estado'] == 'activo' ? 'success' : 'secondary' ?> float-right">
                                                        <?= ucfirst($curso['estado']) ?>
                                                    </span>
                                                </a>
                                                <span class="product-description">
                                                    Inicia: <?= date('d/m/Y', strtotime($curso['fecha_inicio'])) ?>
                                                </span>
                                            </div>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    </section>
                </div>
            </div>
        </section>
    </div>

    <!-- Footer -->
    <footer class="main-footer">
        <strong>Copyright &copy; <?= date('Y') ?> <a href="#">ESIBOC</a>.</strong>
        Todos los derechos reservados.
        <div class="float-right d-none d-sm-inline-block">
            <b>Versión</b> 1.0.0
        </div>
    </footer>
</div>

<!-- REQUIRED SCRIPTS -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/fullcalendar@5.11.3/main.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/fullcalendar@5.11.3/locales/es.min.js"></script>
<script>
$(function () {
    // Calendario
    var calendarEl = document.getElementById('calendar');
    var calendar = new FullCalendar.Calendar(calendarEl, {
        locale: 'es',
        initialView: 'dayGridMonth',
        headerToolbar: {
            left: 'title',
            center: '',
            right: 'prev,next today'
        },
        events: <?= $eventosJson ?>,
        eventClick: function(info) {
            info.jsEvent.preventDefault();
            window.location.href = 'ver_cursos.php?id=' + info.event.id;
        }
    });
    calendar.render();

    // Ajustar calendario al cambiar tamaño
    $(window).resize(function() {
        calendar.updateSize();
    });
});
</script>

<script>
function confirmarCerrarSesion() {
    return confirm("¿Está seguro que desea cerrar sesión?");
}
</script>


</body>
</html>