<?php
session_start();
require_once '../config/database.php';

// Verificar autenticación
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    exit;
}

// Obtener todos los cursos disponibles
$queryCursos = "SELECT id, nombre, fecha_inicio, fecha_fin, 
               numero_registro AS registro, 'Los Santos' AS municipio, 'Santander' AS departamento 
               FROM cursos
               WHERE habilitado = 1
               ORDER BY nombre";
$stmtCursos = $pdo->query($queryCursos);
$todosLosCursos = $stmtCursos->fetchAll(PDO::FETCH_ASSOC);

// Determinar el curso seleccionado
$cursoSeleccionado = isset($_GET['curso_id']) ? (int)$_GET['curso_id'] : null;

// Consulta base para obtener participantes
$query = "SELECT c.id AS curso_id, c.nombre AS nombre_curso, 
          p.id AS participante_id, p.nombres, p.apellidos, p.cedula, p.correo, 
          p.clase_cuerpo_bomberos, p.municipio AS institucion, p.direccion,
          p.archivo_img_fotografia
          FROM cursos c
          JOIN inscripciones i ON c.id = i.curso_id
          JOIN participantes p ON i.participante_id = p.id
          WHERE c.habilitado = 1";

// Aplicar filtro si se seleccionó un curso específico
if ($cursoSeleccionado) {
    $query .= " AND c.id = :curso_id";
}

$query .= " ORDER BY c.nombre, p.apellidos, p.nombres";

$stmt = $pdo->prepare($query);

if ($cursoSeleccionado) {
    $stmt->bindParam(':curso_id', $cursoSeleccionado, PDO::PARAM_INT);
}

$stmt->execute();
$participantes = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Función para obtener la ruta correcta de la foto
function obtenerRutaFoto($rutaBD, $default = '../assets/img/default-photo.jpg') {
    if (empty($rutaBD)) return $default;
    
    $rutaBD = trim($rutaBD);
    
    if (file_exists($rutaBD)) {
        return $rutaBD;
    }
    
    $patrones = [
        '../' . $rutaBD,
        '../uploads/' . basename($rutaBD),
        '../cursos/' . basename(dirname($rutaBD)) . '/' . basename($rutaBD),
        str_replace('\\', '/', $rutaBD)
    ];
    
    foreach ($patrones as $ruta) {
        if (file_exists($ruta)) {
            return $ruta;
        }
    }
    
    return $default;
}

// Agrupar participantes por curso
$cursos = [];
foreach ($participantes as $participante) {
    $cursoId = $participante['curso_id'];
    if (!isset($cursos[$cursoId])) {
        // Buscar información adicional del curso
        foreach ($todosLosCursos as $cursoInfo) {
            if ($cursoInfo['id'] == $cursoId) {
                $cursos[$cursoId] = [
                    'nombre' => $participante['nombre_curso'],
                    'fecha_inicio' => $cursoInfo['fecha_inicio'],
                    'fecha_fin' => $cursoInfo['fecha_fin'],
                    'registro' => $cursoInfo['registro'],
                    'municipio' => $cursoInfo['municipio'],
                    'departamento' => $cursoInfo['departamento'],
                    'participantes' => []
                ];
                break;
            }
        }
    }
    $cursos[$cursoId]['participantes'][] = $participante;
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Directorio de Participantes | ESIBOC</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <style>
        /* Estilos para pantalla */
        body {
            background-color: #f8f9fa;
            padding: 20px;
            font-family: 'Segoe UI', Tahoma, Geneva, Verdana, sans-serif;
        }
        .portada-curso {
            background-color: #ffffff;
            border-radius: 8px;
            padding: 30px;
            margin-bottom: 30px;
            box-shadow: 0 4px 12px rgba(0,0,0,0.1);
            text-align: center;
        }
        .portada-header h2 {
            color: #dc3545;
            font-weight: 700;
            margin-bottom: 5px;
        }
        .portada-header h3 {
            color: #007bff;
            font-weight: 600;
        }
        .portada-titulo-curso {
            background-color: #007bff;
            color: white;
            padding: 10px;
            border-radius: 5px;
            margin: 15px 0;
            display: inline-block;
        }
        .portada-info-curso {
            display: flex;
            justify-content: center;
            gap: 30px;
            margin: 20px 0;
            flex-wrap: wrap;
        }
        .portada-info-item {
            background-color: #f8f9fa;
            padding: 10px 20px;
            border-radius: 5px;
            border-left: 4px solid #007bff;
        }
        .portada-lugar {
            font-size: 1.2rem;
            color: #343a40;
            margin-top: 15px;
            font-weight: 500;
        }
        .participantes-container {
            display: flex;
            flex-wrap: wrap;
            gap: 15px;
            margin-bottom: 30px;
        }
        .participante-card {
            border: 1px solid #dee2e6;
            border-radius: 6px;
            padding: 15px;
            background-color: white;
            box-shadow: 0 1px 5px rgba(0,0,0,0.05);
            width: calc(50% - 8px);
            display: flex;
        }
        .foto-container {
            flex-shrink: 0;
            margin-right: 15px;
        }
        .participante-foto {
            width: 80px;
            height: 80px;
            border-radius: 50%;
            object-fit: cover;
            border: 2px solid #007bff;
        }
        .foto-placeholder {
            width: 80px;
            height: 80px;
            border-radius: 50%;
            background: linear-gradient(135deg, #6c757d, #495057);
            display: flex;
            align-items: center;
            justify-content: center;
            color: white;
            border: 2px solid #007bff;
        }
        .participante-info {
            flex-grow: 1;
        }
        .participante-info h4 {
            color: #343a40;
            margin-bottom: 8px;
            font-weight: 600;
            font-size: 1rem;
        }
        .participante-info p {
            margin-bottom: 6px;
            color: #495057;
            font-size: 0.9rem;
        }
        .sigla-cb {
            font-weight: bold;
            color: #dc3545;
            background-color: #f8f9fa;
            padding: 1px 4px;
            border-radius: 3px;
            font-size: 0.85em;
        }
        .separador-curso {
            height: 1px;
            background: linear-gradient(to right, transparent, #007bff, transparent);
            margin: 30px 0;
        }
        .filtro-container {
            background-color: #ffffff;
            padding: 15px;
            border-radius: 6px;
            margin-bottom: 25px;
            box-shadow: 0 1px 8px rgba(0,0,0,0.05);
        }
        .btn-generar {
            background-color: #28a745;
            border-color: #28a745;
        }
        .btn-todos {
            background-color: #17a2b8;
            border-color: #17a2b8;
        }
        .btn-print {
            position: fixed;
            bottom: 20px;
            right: 20px;
            z-index: 1000;
            padding: 12px 20px;
            font-size: 1rem;
        }

        /* Estilos optimizados para impresión */
        @media print {
    @page {
        size: letter;
        margin: 0.5cm 0.3cm !important;
    }
    
    body {
        padding: 0 0.2cm !important;
        background: none !important;
        font-size: 8pt !important;
    }
    
    .no-print {
        display: none !important;
    }
    
    .container {
        max-width: 100% !important;
        padding: 0 0.2cm !important;
        margin: 0 auto !important;
    }
    
    .portada-curso {
        page-break-after: always;
        margin: 0 0 0.5cm 0 !important;
        padding: 0.3cm !important;
        box-shadow: none !important;
    }
    
    .participantes-container {
        display: flex !important;
        flex-wrap: wrap !important;
        gap: 0.2cm !important;
        margin: 0 !important;
        justify-content: flex-start !important;
        width: 100% !important;
    }
    
    .participante-card {
        width: 48% !important; /* Cambiado a porcentaje fijo */
        margin: 0 1% 0.2cm 0 !important; /* Margen derecho del 1% */
        padding: 0.2cm !important;
        page-break-inside: avoid;
        break-inside: avoid;
        border: 1px solid #eee !important;
        display: flex !important;
        align-items: flex-start !important;
        text-align: left !important;
        float: left !important; /* Añadido para forzar el layout */
        box-sizing: border-box !important; /* Asegura que el padding no afecte el ancho */
    }
    
    .foto-container {
        margin-right: 0.2cm !important;
        flex-shrink: 0 !important;
    }
    
    .participante-foto, .foto-placeholder {
        width: 35px !important;
        height: 35px !important;
        border-width: 1px !important;
    }
    
    .participante-info {
        flex-grow: 1 !important;
        text-align: left !important; /* Asegurar alineación izquierda */
    }
    
    .participante-info h4 {
        font-size: 9pt !important;
        margin-bottom: 2px !important;
        text-align: left !important;
    }
    
    .participante-info p {
        font-size: 7pt !important;
        margin-bottom: 1px !important;
        line-height: 1.1 !important;
        text-align: left !important;
    }
    
    /* Optimización de elementos de la portada */
    .portada-header h2 {
        font-size: 12pt !important;
        margin-bottom: 3px !important;
    }
    
    .portada-header h3 {
        font-size: 10pt !important;
    }
    
    .portada-titulo-curso h4 {
        font-size: 10pt !important;
        padding: 3px 5px !important;
    }
    
    .portada-info-item {
        padding: 2px 5px !important;
        font-size: 8pt !important;
    }
    
    .separador-curso {
        display: none;
    }
}
    </style>
</head>
<body>
    <div class="container">
        <div class="d-flex justify-content-between align-items-center mb-4 no-print">
            <h1 style="color: #007bff;">Directorio de Participantes</h1>
        </div>
        
        <!-- Filtro por curso -->
        <div class="filtro-container mb-4 no-print">
            <form method="get" action="" class="row g-3">
                <div class="col-md-8">
                    <label for="curso_id" class="form-label">Seleccionar Curso</label>
                    <select class="form-select" id="curso_id" name="curso_id">
                        <option value="">-- Todos los cursos --</option>
                        <?php foreach ($todosLosCursos as $curso): ?>
                            <option value="<?= $curso['id'] ?>" <?= ($cursoSeleccionado == $curso['id']) ? 'selected' : '' ?>>
                                <?= htmlspecialchars($curso['nombre']) ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-4 d-flex align-items-end">
                    <button type="submit" class="btn btn-generar text-white me-2">
                        <i class="fas fa-filter me-1"></i> Filtrar
                    </button>
                    <a href="?" class="btn btn-todos text-white">
                        <i class="fas fa-list me-1"></i> Ver todos
                    </a>
                </div>
            </form>
        </div>

        <?php if (empty($cursos)): ?>
            <div class="alert alert-info">
                No hay participantes registrados para el curso seleccionado.
            </div>
        <?php else: ?>
            <?php foreach ($cursos as $cursoId => $curso): ?>
                <!-- Portada del curso -->
                <div class="portada-curso">
                    <div class="portada-header">
                        <h2>Dirección Nacional de Bomberos de Colombia</h2>
                        <h3>CBV de <?= htmlspecialchars($curso['municipio']) ?>, <?= htmlspecialchars($curso['departamento']) ?></h3>
                    </div>
                    
                    <div class="portada-titulo-curso">
                        <h4 class="mb-0">Curso <?= htmlspecialchars($curso['nombre']) ?> - Reg. <?= htmlspecialchars($curso['registro']) ?></h4>
                    </div>
                    
                    <div class="portada-info-curso">
                        <div class="portada-info-item">
                            <strong>Fecha de inicio:</strong> 
                            <?= date('d/m/Y', strtotime($curso['fecha_inicio'])) ?>
                        </div>
                        <div class="portada-info-item">
                            <strong>Fecha de finalización:</strong> 
                            <?= date('d/m/Y', strtotime($curso['fecha_fin'])) ?>
                        </div>
                    </div>
                    
                    <div class="portada-lugar">
                        <i class="fas fa-map-marker-alt"></i> 
                        <?= htmlspecialchars($curso['municipio']) ?> - <?= htmlspecialchars($curso['departamento']) ?>
                    </div>
                </div>
                
                <!-- Listado de participantes -->
                <div class="participantes-container">
                    <?php foreach ($curso['participantes'] as $participante): 
                        $rutaFoto = obtenerRutaFoto($participante['archivo_img_fotografia']);
                        $fotoExiste = $rutaFoto && file_exists($rutaFoto);
                    ?>
                        <div class="participante-card">
                            <div class="foto-container">
                                <?php if ($fotoExiste): ?>
                                    <img src="<?= htmlspecialchars($rutaFoto) ?>" 
                                         class="participante-foto" 
                                         alt="Foto de <?= htmlspecialchars($participante['nombres']) ?>"
                                         onerror="this.onerror=null; this.parentElement.innerHTML='<div class=\'foto-placeholder\'><i class=\'fas fa-user fa-2x\'></i></div>'">
                                <?php else: ?>
                                    <div class="foto-placeholder">
                                        <i class="fas fa-user fa-2x"></i>
                                    </div>
                                <?php endif; ?>
                            </div>
                            
                            <div class="participante-info">
                                <h4><?= htmlspecialchars($participante['nombres'] . ' ' . $participante['apellidos']) ?></h4>
                                <p><strong><i class="fas fa-id-card me-1"></i> Cédula:</strong> <?= htmlspecialchars($participante['cedula']) ?></p>
                                <p><strong><i class="fas fa-envelope me-1"></i> Correo:</strong> <?= htmlspecialchars($participante['correo']) ?></p>
                                <p>
                                    <strong><i class="fas fa-building me-1"></i> Institución:</strong> 
                                    <span class="sigla-cb">CB<?= strtoupper(substr($participante['clase_cuerpo_bomberos'], 0, 1)) ?></span>
                                    <?= htmlspecialchars($participante['institucion']) ?>
                                </p>
                                <p><strong><i class="fas fa-home me-1"></i> Dirección:</strong> <?= htmlspecialchars($participante['direccion']) ?></p>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
                
                <div class="separador-curso"></div>
            <?php endforeach; ?>
        <?php endif; ?>
    </div>

    <button onclick="window.print()" class="btn btn-primary btn-print no-print">
        <i class="fas fa-print me-2"></i> Imprimir Directorio
    </button>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Manejo de errores en imágenes
            document.querySelectorAll('.participante-foto').forEach(img => {
                img.onerror = function() {
                    this.parentElement.innerHTML = '<div class="foto-placeholder"><i class="fas fa-user fa-2x"></i></div>';
                };
            });
            
            // Configuración para impresión
            window.beforePrint = function() {
                console.log('Preparando para imprimir...');
            };
            
            window.afterPrint = function() {
                console.log('Impresión completada');
            };
        });
    </script>
</body>
</html>