<?php
session_start();
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    exit;
}

require_once '../config/database.php';

// Cambiar estado del curso
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['curso_id']) && isset($_POST['nuevo_estado'])) {
    $stmt = $pdo->prepare("UPDATE cursos SET estado = ? WHERE id = ?");
    $stmt->execute([$_POST['nuevo_estado'], $_POST['curso_id']]);
    $_SESSION['success'] = "Estado del curso actualizado correctamente.";
    header("Location: gestionar_estado_cursos.php");
    exit;
}

// Obtener todos los cursos
$stmt = $pdo->query("SELECT * FROM cursos ORDER BY fecha_inicio DESC");
$cursos = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Gestionar Estado de Cursos | ESIBOC</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">
    <!-- Navbar y Sidebar (copiar de tu archivo existente) -->

    <div class="content-wrapper">
        <section class="content">
            <div class="container-fluid">
                <?php if (isset($_SESSION['success'])): ?>
                    <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
                    <?php unset($_SESSION['success']); ?>
                <?php endif; ?>
                
                <div class="card">
                    <div class="card-header">
                        <h3 class="card-title">Gestionar Estado de Cursos</h3>
                    </div>
                    <div class="card-body">
                        <table class="table table-bordered">
                            <thead>
                                <tr>
                                    <th>Nombre</th>
                                    <th>Fecha Inicio</th>
                                    <th>Estado</th>
                                    <th>Acciones</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($cursos as $curso): ?>
                                <tr>
                                    <td><?= htmlspecialchars($curso['nombre']) ?></td>
                                    <td><?= date('d/m/Y', strtotime($curso['fecha_inicio'])) ?></td>
                                    <td>
                                        <span class="badge badge-<?= $curso['estado'] == 'activo' ? 'success' : 'danger' ?>">
                                            <?= strtoupper($curso['estado']) ?>
                                        </span>
                                    </td>
                                    <td>
                                        <form method="POST" style="display:inline;">
                                            <input type="hidden" name="curso_id" value="<?= $curso['id'] ?>">
                                            <input type="hidden" name="nuevo_estado" value="<?= $curso['estado'] == 'activo' ? 'inactivo' : 'activo' ?>">
                                            <button type="submit" class="btn btn-sm btn-<?= $curso['estado'] == 'activo' ? 'danger' : 'success' ?>">
                                                <?= $curso['estado'] == 'activo' ? 'Desactivar' : 'Activar' ?>
                                            </button>
                                        </form>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </section>
    </div>
</div>
</body>
</html>