<?php
require_once '../config/database.php';

header('Content-Type: application/json');

if (!isset($_GET['curso_id']) || !is_numeric($_GET['curso_id'])) {
    echo json_encode(['success' => false, 'message' => 'ID de curso inválido']);
    exit;
}

$curso_id = (int)$_GET['curso_id'];

try {
    // Obtener participantes agrupados por municipio
    $stmt = $pdo->prepare("
        SELECT p.municipio, COUNT(*) as conteo 
        FROM participantes p
        INNER JOIN inscripciones i ON p.id = i.participante_id
        WHERE i.curso_id = ?
        GROUP BY p.municipio
        ORDER BY conteo DESC
    ");
    $stmt->execute([$curso_id]);
    $resultados = $stmt->fetchAll(PDO::FETCH_ASSOC);

    if (empty($resultados)) {
        echo json_encode(['success' => false, 'message' => 'No hay participantes en este curso']);
        exit;
    }

    // Obtener total de participantes
    $stmtTotal = $pdo->prepare("
        SELECT COUNT(*) as total
        FROM inscripciones
        WHERE curso_id = ?
    ");
    $stmtTotal->execute([$curso_id]);
    $total = $stmtTotal->fetchColumn();

    // Preparar datos para el gráfico
    $municipios = [];
    $conteos = [];
    $porcentajes = [];

    foreach ($resultados as $row) {
        $municipios[] = $row['municipio'];
        $conteos[] = (int)$row['conteo'];
        $porcentajes[] = round(($row['conteo'] / $total) * 100, 2);
    }

    // Generar colores aleatorios para el gráfico
    $colores = [];
    foreach ($municipios as $m) {
        $colores[] = sprintf('#%06X', mt_rand(0, 0xFFFFFF));
    }

    echo json_encode([
        'success' => true,
        'municipios' => $municipios,
        'conteos' => $conteos,
        'porcentajes' => $porcentajes,
        'total' => $total,
        'colores' => $colores
    ]);

} catch (Exception $e) {
    echo json_encode(['success' => false, 'message' => 'Error: ' . $e->getMessage()]);
}

