<?php
session_start();

// Configuración de rutas base dinámicas
$protocol = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? 'https://' : 'http://');
$host = $_SERVER['HTTP_HOST'];
$app_path = '/esiboc'; // Cambia esto si tu aplicación no está en /esiboc
$base_url = $protocol . $host . $app_path;
$base_dir = __DIR__; // Ruta absoluta al directorio actual

// Configuración de acceso
$es_admin = isset($_SESSION['admin_id']);
$requiere_login = false; // Cambiar a true si se desea forzar login para inscripción

if ($requiere_login && !$es_admin) {
    header("Location: $base_url/login.php");
    exit;
}

require_once $base_dir . '/../config/database.php';

// Función para redimensionar imágenes
function redimensionarImagen($rutaOriginal, $rutaDestino, $anchoDeseado, $altoDeseado) {
    $info = getimagesize($rutaOriginal);
    if (!$info) {
        return false;
    }
    
    $anchoOriginal = $info[0];
    $altoOriginal = $info[1];
    $tipo = $info[2];

    switch ($tipo) {
        case IMAGETYPE_JPEG:
            $imagenOriginal = imagecreatefromjpeg($rutaOriginal);
            break;
        case IMAGETYPE_PNG:
            $imagenOriginal = imagecreatefrompng($rutaOriginal);
            break;
        default:
            return false;
    }

    $imagenRedimensionada = imagecreatetruecolor($anchoDeseado, $altoDeseado);

    if ($tipo == IMAGETYPE_PNG) {
        imagealphablending($imagenRedimensionada, false);
        imagesavealpha($imagenRedimensionada, true);
        $transparente = imagecolorallocatealpha($imagenRedimensionada, 255, 255, 255, 127);
        imagefilledrectangle($imagenRedimensionada, 0, 0, $anchoDeseado, $altoDeseado, $transparente);
    } else {
        $blanco = imagecolorallocate($imagenRedimensionada, 255, 255, 255);
        imagefill($imagenRedimensionada, 0, 0, $blanco);
    }

    $ratioOriginal = $anchoOriginal / $altoOriginal;
    $ratioDeseado = $anchoDeseado / $altoDeseado;

    if ($ratioOriginal >= $ratioDeseado) {
        $nuevoAncho = $anchoDeseado;
        $nuevoAlto = $anchoDeseado / $ratioOriginal;
    } else {
        $nuevoAlto = $altoDeseado;
        $nuevoAncho = $altoDeseado * $ratioOriginal;
    }

    $x = ($anchoDeseado - $nuevoAncho) / 2;
    $y = ($altoDeseado - $nuevoAlto) / 2;

    imagecopyresampled(
        $imagenRedimensionada, $imagenOriginal,
        $x, $y, 0, 0,
        $nuevoAncho, $nuevoAlto,
        $anchoOriginal, $altoOriginal
    );

    switch ($tipo) {
        case IMAGETYPE_JPEG:
            imagejpeg($imagenRedimensionada, $rutaDestino, 90);
            break;
        case IMAGETYPE_PNG:
            imagepng($imagenRedimensionada, $rutaDestino, 9);
            break;
    }

    imagedestroy($imagenOriginal);
    imagedestroy($imagenRedimensionada);

    return true;
}

// Obtener cursos disponibles
if ($es_admin) {
    $stmt = $pdo->query("SELECT 
    c.*, 
    (SELECT COUNT(*) FROM inscripciones WHERE curso_id = c.id) as inscritos,
    GREATEST(0, c.cupo_maximo - (SELECT COUNT(*) FROM inscripciones WHERE curso_id = c.id)) as cupos_disponibles
    FROM cursos c 
    WHERE c.estado = 'activo' AND c.habilitado = 1
    ORDER BY c.fecha_inicio DESC");
} else {
    $stmt = $pdo->query("SELECT 
        c.*, 
        (SELECT COUNT(*) FROM inscripciones WHERE curso_id = c.id) as inscritos,
        GREATEST(0, c.cupo_maximo - (SELECT COUNT(*) FROM inscripciones WHERE curso_id = c.id)) as cupos_disponibles
        FROM cursos c 
        WHERE c.estado = 'activo' AND c.habilitado = 1
        ORDER BY c.fecha_inicio DESC");
}


$cursos = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Array completo de departamentos y municipios de Colombia
$departamentos = [
    'Amazonas' => ['Leticia', 'Puerto Nariño'],
    'Antioquia' => ['Medellín', 'Bello', 'Itagüí', 'Envigado', 'Apartadó', 'Turbo', 'Rionegro', 'Marinilla', 'Santuario'],
    'Arauca' => ['Arauca', 'Saravena', 'Fortul'],
    'Atlántico' => ['Barranquilla', 'Soledad', 'Malambo', 'Sabanalarga'],
    'Bolívar' => ['Cartagena', 'Magangué', 'Turbaco', 'Arjona'],
    'Boyacá' => ['Tunja', 'Duitama', 'Sogamoso', 'Chiquinquirá'],
    'Caldas' => ['Manizales', 'La Dorada', 'Chinchiná'],
    'Caquetá' => ['Florencia', 'San Vicente del Caguán'],
    'Casanare' => ['Yopal', 'Aguazul', 'Tauramena'],
    'Cauca' => ['Popayán', 'Santander de Quilichao'],
    'Cesar' => ['Valledupar', 'Aguachica', 'Codazzi'],
    'Chocó' => ['Quibdó', 'Istmina', 'Tadó'],
    'Córdoba' => ['Montería', 'Lorica', 'Sahagún'],
    'Cundinamarca' => ['Bogotá', 'Soacha', 'Girardot', 'Facatativá', 'Zipaquirá'],
    'Guainía' => ['Inírida'],
    'Guaviare' => ['San José del Guaviare'],
    'Huila' => ['Neiva', 'Pitalito', 'Garzón'],
    'La Guajira' => ['Riohacha', 'Maicao', 'Uribia'],
    'Magdalena' => ['Santa Marta', 'Ciénaga', 'Fundación'],
    'Meta' => ['Villavicencio', 'Acacías', 'Granada'],
    'Nariño' => ['Pasto', 'Ipiales', 'Tumaco'],
    'Norte de Santander' => ['Cúcuta', 'Ocaña', 'Pamplona'],
    'Putumayo' => ['Mocoa', 'Puerto Asís'],
    'Quindío' => ['Armenia', 'Calarcá', 'La Tebaida'],
    'Risaralda' => ['Pereira', 'Dosquebradas', 'Santa Rosa de Cabal'],
    'San Andrés y Providencia' => ['San Andrés', 'Providencia'],
    'Santander' => ['Bucaramanga', 'Floridablanca', 'Girón', 'Piedecuesta', 'Barrancabermeja'],
    'Sucre' => ['Sincelejo', 'Corozal', 'Sampués'],
    'Tolima' => ['Ibagué', 'Espinal', 'Honda'],
    'Valle del Cauca' => ['Cali', 'Palmira', 'Buenaventura', 'Tuluá', 'Buga', 'Cartago'],
    'Vaupés' => ['Mitú'],
    'Vichada' => ['Puerto Carreño']
];

// Manejar el formulario de inscripción
$error = '';
$success = '';
$cupos_agotados = false;

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Recoger datos del formulario
    $nombres = $_POST['nombres'];
    $apellidos = $_POST['apellidos'];
    $cedula = $_POST['cedula'];
    $sexo = $_POST['sexo'];
    $celular = $_POST['celular'];
    $correo = $_POST['correo'];
    $direccion = $_POST['direccion'];
    $clase_cuerpo_bomberos = $_POST['clase_cuerpo_bomberos'];
    $departamento = $_POST['departamento'];
    $municipio = $_POST['municipio'];
    $curso_id = $_POST['curso_id'];
    $codigo_acceso = $_POST['codigo_acceso'] ?? '';

    try {
        // Iniciar transacción con bloqueo
        $pdo->beginTransaction();
        
        // Bloquear el curso para evitar conflictos
        $stmt = $pdo->prepare("SELECT habilitado, nombre, numero_registro, cupo_maximo, es_exclusivo, codigo_acceso 
                             FROM cursos WHERE id = ? FOR UPDATE");
        $stmt->execute([$curso_id]);
        $curso = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$curso || $curso['habilitado'] != 1) {
            throw new Exception("El curso seleccionado no está habilitado para inscripciones.");
        }
        
        // Validar código de acceso para cursos exclusivos
        if ($curso['es_exclusivo']) {
            if (empty($codigo_acceso)) {
                throw new Exception("Este curso es exclusivo y requiere un código de acceso.");
            }
            
            if ($codigo_acceso !== $curso['codigo_acceso']) {
                throw new Exception("El código de acceso proporcionado no es válido para este curso.");
            }
        }

        // Verificar cupos disponibles (con el bloqueo activo)
        $stmt = $pdo->prepare("SELECT COUNT(*) as inscritos 
                              FROM inscripciones WHERE curso_id = ?");
        $stmt->execute([$curso_id]);
        $inscritos = $stmt->fetch(PDO::FETCH_ASSOC)['inscritos'];
        
        $cupos_disponibles = $curso['cupo_maximo'] - $inscritos;
        
        if ($cupos_disponibles <= 0) {
            throw new Exception("No hay cupos disponibles para este curso.");
        }

        // Verificar si el correo ya está registrado en este curso (para otro participante)
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM participantes p 
                            JOIN inscripciones i ON p.id = i.participante_id 
                            WHERE p.correo = ? AND i.curso_id = ? AND p.cedula != ?");
        $stmt->execute([$correo, $curso_id, $cedula]);
        $correo_existente = $stmt->fetchColumn();

        if ($correo_existente > 0) {
            throw new Exception("Ya existe otro participante inscrito en este curso con el mismo correo electrónico.");
        }

        // Crear estructura de carpetas
        $carpetaBaseCursos = $base_dir . '/../cursos/';
        if (!file_exists($carpetaBaseCursos)) {
            mkdir($carpetaBaseCursos, 0777, true);
        }

        // Nombre de la carpeta del curso
        $nombreCarpetaCurso = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $curso['nombre'])) . '_' . $curso['numero_registro'];
        $rutaCarpetaCurso = $carpetaBaseCursos . $nombreCarpetaCurso;

        // Crear carpeta del participante dentro de la carpeta del curso
        $nombreCarpetaParticipante = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $nombres . '_' . $apellidos)) . '_' . $cedula;
        $rutaCarpetaParticipante = $rutaCarpetaCurso . '/' . $nombreCarpetaParticipante;

        if (!file_exists($rutaCarpetaParticipante)) {
            if (!mkdir($rutaCarpetaParticipante, 0777, true)) {
                throw new Exception("Error al crear la carpeta del participante. Por favor, verifique los permisos.");
            }
        }

        // Procesar archivos y guardar en la carpeta creada
        $uploadDir = $rutaCarpetaParticipante . '/';
        $archivos = [];

        // Procesar cada archivo
        $archivosPermitidos = [
            'archivo_pdf_cedula',
            'archivo_img_fotografia',
            'archivo_pdf_comprobante_pago',
            'archivo_pdf_oficio_postulacion',
            'archivo_pdf_certificado_formacion',
            'archivo_pdf_rut'
        ];

        foreach ($archivosPermitidos as $campo) {
            if (isset($_FILES[$campo]) && $_FILES[$campo]['error'] === UPLOAD_ERR_OK) {
                $ext = pathinfo($_FILES[$campo]['name'], PATHINFO_EXTENSION);
                $nombreBase = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $nombres . '_' . $apellidos)) . '_' . $cedula;
                
                // Nombres personalizados para cada tipo de archivo
                switch ($campo) {
                    case 'archivo_img_fotografia':
                        $nombreArchivo = 'foto_' . $nombreBase . '.' . $ext;
                        break;
                    case 'archivo_pdf_cedula':
                        $nombreArchivo = 'cedula_' . $nombreBase . '.' . $ext;
                        break;
                    case 'archivo_pdf_comprobante_pago':
                        $nombreArchivo = 'pago_' . $nombreBase . '.' . $ext;
                        break;
                    case 'archivo_pdf_oficio_postulacion':
                        $nombreArchivo = 'postulacion_' . $nombreBase . '.' . $ext;
                        break;
                    case 'archivo_pdf_certificado_formacion':
                        $nombreArchivo = 'certificado_' . $nombreBase . '.' . $ext;
                        break;
                    case 'archivo_pdf_rut':
                        $nombreArchivo = 'rut_' . $nombreBase . '.' . $ext;
                        break;
                    default:
                        $nombreArchivo = $campo . '_' . $nombreBase . '.' . $ext;
                }
                
                $rutaArchivo = $uploadDir . $nombreArchivo;
                
                if (move_uploaded_file($_FILES[$campo]['tmp_name'], $rutaArchivo)) {
                    // Si es la fotografía del participante, redimensionarla
                    if ($campo === 'archivo_img_fotografia') {
                        $rutaTemp = $uploadDir . 'temp_' . $nombreArchivo;
                        rename($rutaArchivo, $rutaTemp); // Mover a temporal
                        
                        // Redimensionar a 300x300 píxeles
                        if (redimensionarImagen($rutaTemp, $rutaArchivo, 300, 300)) {
                            unlink($rutaTemp); // Eliminar el temporal
                        } else {
                            rename($rutaTemp, $rutaArchivo); // Si falla, mantener el original
                            throw new Exception("Error al redimensionar la imagen. Se ha guardado la imagen original.");
                        }
                    }
                    
                    $archivos[$campo] = $nombreArchivo;
                } else {
                    throw new Exception("Error al subir el archivo " . $campo);
                }
            } elseif ($campo !== 'archivo_pdf_rut') {
                throw new Exception("El archivo " . str_replace('_', ' ', $campo) . " es requerido");
            }
        }

        // Verificar si el participante ya existe
        $stmt = $pdo->prepare("SELECT id FROM participantes WHERE cedula = ? LIMIT 1");
        $stmt->execute([$cedula]);
        $participante_existente = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($participante_existente) {
            // Usar el participante existente
            $participante_id = $participante_existente['id'];
            
            // Actualizar datos del participante
            $stmt = $pdo->prepare("UPDATE participantes SET 
                nombres = ?, apellidos = ?, sexo = ?, celular = ?, correo = ?, direccion = ?,
                clase_cuerpo_bomberos = ?, departamento = ?, municipio = ?,
                archivo_pdf_cedula = COALESCE(?, archivo_pdf_cedula),
                archivo_img_fotografia = COALESCE(?, archivo_img_fotografia),
                archivo_pdf_comprobante_pago = COALESCE(?, archivo_pdf_comprobante_pago),
                archivo_pdf_oficio_postulacion = COALESCE(?, archivo_pdf_oficio_postulacion),
                archivo_pdf_certificado_formacion = COALESCE(?, archivo_pdf_certificado_formacion),
                archivo_pdf_rut = COALESCE(?, archivo_pdf_rut)
                WHERE id = ?");
            
            $stmt->execute([
                $nombres, $apellidos, $sexo, $celular, $correo, $direccion,
                $clase_cuerpo_bomberos, $departamento, $municipio,
                $archivos['archivo_pdf_cedula'] ?? null,
                $archivos['archivo_img_fotografia'] ?? null,
                $archivos['archivo_pdf_comprobante_pago'] ?? null,
                $archivos['archivo_pdf_oficio_postulacion'] ?? null,
                $archivos['archivo_pdf_certificado_formacion'] ?? null,
                $archivos['archivo_pdf_rut'] ?? null,
                $participante_id
            ]);
        } else {
            // Insertar nuevo participante
            $stmt = $pdo->prepare("INSERT INTO participantes 
                (nombres, apellidos, cedula, sexo, celular, correo, direccion, 
                clase_cuerpo_bomberos, departamento, municipio, 
                archivo_pdf_cedula, archivo_img_fotografia, archivo_pdf_comprobante_pago, 
                archivo_pdf_oficio_postulacion, archivo_pdf_certificado_formacion, archivo_pdf_rut) 
                VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
            
            $stmt->execute([
                $nombres, $apellidos, $cedula, $sexo, $celular, $correo, $direccion,
                $clase_cuerpo_bomberos, $departamento, $municipio,
                $archivos['archivo_pdf_cedula'] ?? '',
                $archivos['archivo_img_fotografia'] ?? '',
                $archivos['archivo_pdf_comprobante_pago'] ?? '',
                $archivos['archivo_pdf_oficio_postulacion'] ?? '',
                $archivos['archivo_pdf_certificado_formacion'] ?? '',
                $archivos['archivo_pdf_rut'] ?? null
            ]);
            
            $participante_id = $pdo->lastInsertId();
        }
        
        // Verificar que el participante no esté ya inscrito en ESTE CURSO
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM inscripciones 
                            WHERE participante_id = ? AND curso_id = ?");
        $stmt->execute([$participante_id, $curso_id]);
        $ya_inscrito = $stmt->fetchColumn();
        
        if ($ya_inscrito > 0) {
            throw new Exception("Este participante ya está inscrito en este curso.");
        }
        
        // Insertar inscripción
        $stmt = $pdo->prepare("INSERT INTO inscripciones 
            (participante_id, curso_id) 
            VALUES (?, ?)");
        $stmt->execute([$participante_id, $curso_id]);
        
        $pdo->commit();
        
        $success = "Participante inscrito correctamente en el curso.";
    } catch (PDOException $e) {
        $pdo->rollBack();
        $error = "Error al registrar la inscripción: " . $e->getMessage();
       $cupos_agotados = (strpos($e->getMessage(), "No hay cupos disponibles") !== false);
    } catch (Exception $e) {
        $pdo->rollBack();
        $error = $e->getMessage();
        $cupos_agotados = (strpos($e->getMessage(), "No hay cupos disponibles") !== false);
    }
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Inscripción de Participante | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <style>
        .section-title {
            font-size: 1.1rem;
            color: #007bff;
            border-bottom: 1px solid #dee2e6;
            padding-bottom: 0.5rem;
            margin-bottom: 1.5rem;
        }
        .file-info {
            font-size: 0.8rem;
            color: #6c757d;
            margin-top: 0.25rem;
        }
        .cupos-container {
            margin-top: 0.5rem;
        }
        .cupos-info {
            padding: 0.5rem;
            border-radius: 4px;
            font-weight: 500;
            display: flex;
            align-items: center;
        }
        .cupos-disponibles {
            background-color: #d4edda;
            color: #155724;
        }
        .cupos-agotados {
            background-color: #990000;
            color: #990000;
        }
        .cupos-deshabilitado {
            background-color: #e2e3e5;
            color: #383d41;
        }
        .status-icon {
            margin-right: 0.5rem;
        }
        .validation-message {
            display: block;
            margin-top: 0.25rem;
            font-size: 0.875rem;
        }
        .valid-feedback {
            color: #28a745;
        }
        .invalid-feedback {
            color: #dc3545;
        }
        .form-section {
            margin-bottom: 2rem;
        }
        .btn-group {
            display: flex;
            justify-content: flex-end;
            gap: 1rem;
            margin-top: 2rem;
        }
        .fixed {
            position: fixed;
            height: 100vh;
            overflow-y: auto;
        }
        .form-disabled {
            opacity: 0.7;
            pointer-events: none;
        }
        .form-disabled input:not(#curso_id), 
        .form-disabled select, 
        .form-disabled textarea, 
        .form-disabled button {
            background-color: #e9ecef;
            cursor: not-allowed;
        }
        .correo-invalido {
            border-color: #dc3545;
        }
        .correo-valido {
            border-color: #28a745;
        }
        /* Estilos para versión pública */
        .public-version .main-header {
            background-color: #007bff;
        }
        .public-version .navbar-light .navbar-nav .nav-link {
            color: rgba(255,255,255,0.9);
        }
        .public-version .navbar-light .navbar-nav .nav-link:hover {
            color: white;
        }
        .public-version .card-primary {
            border-top: 3px solid #007bff;
        }
        /* Barra de progreso personalizada */
        .progress {
            background-color: #e9ecef;
            border-radius: 0.25rem;
            overflow: hidden;
        }
        .progress-bar {
            display: flex;
            align-items: center;
            justify-content: center;
            font-size: 0.75rem;
            font-weight: bold;
        }
        
        /* Colores mejorados para la barra de progreso */
.progress-bar-success {
    background-color: #006837; /* Verde oscuro */
    color: white;
}

.progress-bar-warning {
    background-color: #E67E22; /* Naranja */
    color: white;
}

.progress-bar-danger {
    background-color: #FFD700; /* Rojo oscuro */
    color: #000;
}

/* Estilo adicional para mejor contraste */
.progress-bar {
    text-shadow: 0 1px 1px rgba(0,0,0,0.3);
    box-shadow: inset 0 1px 1px rgba(0,0,0,0.1);
    transition: width 0.3s ease;
}

/* Timestamp mejorado para todos los estados */
.alert .text-muted {
    font-size: 0.7rem;
    display: block;
    margin-top: 8px;
}

.alert-success .text-muted {
    color: #245d3e !important; /* Verde oscuro */
}

.alert-warning .text-muted {
    color: #856404 !important; /* Ámbar oscuro */
}

.alert-danger .text-muted {
    color: #ffebee !important; /* Rojo claro/rosa pálido */
    text-shadow: 0 1px 1px rgba(0,0,0,0.2);
}

.alert-info .text-muted {
    color: #0c5460 !important; /* Azul oscuro */
}

#cupos-container .alert-danger {
    background-color: #990000 !important;
    color: #fff !important;
}

        
    </style>
</head>
<body class="hold-transition <?php echo $es_admin ? 'sidebar-mini' : 'public-version'; ?> layout-fixed">
<div class="wrapper">

    <!-- Navbar - Diferente para admin vs público -->
    <?php if ($es_admin): ?>
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Navbar para administrador -->
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#" role="button"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="<?php echo $base_url; ?>/admin/dashboard.php" class="nav-link">Inicio</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="<?php echo $base_url; ?>/admin/ver_cursos.php" class="nav-link">Cursos</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="<?php echo $base_url; ?>/admin/inscribir_participante.php" class="nav-link active">Inscribir Participante</a>
            </li>
        </ul>
    </nav>
    <?php else: ?>
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Navbar para público -->
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a href="<?php echo $base_url; ?>/index.php" class="nav-link">Inicio</a>
            </li>
            <li class="nav-item">
                <a href="<?php echo $base_url; ?>/admin/inscribir_participante.php" class="nav-link active">Inscripción</a>
            </li>
            <?php if (!$es_admin): ?>
            <li class="nav-item">
            <a href="<?php echo $base_url; ?>/login" class="nav-link">Acceso Administradores</a>
            </li>
            <?php endif; ?>
        </ul>
    </nav>
    <?php endif; ?>

    <!-- Sidebar - Solo para admin -->
    <?php if ($es_admin): ?>
    <aside class="main-sidebar sidebar-dark-primary elevation-4 fixed">
        <!-- Brand Logo -->
        <a href="<?php echo $base_url; ?>/admin/dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>

        <!-- Sidebar -->
        <div class="sidebar">
            <!-- Sidebar user panel -->
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" 
                          style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?php echo strtoupper(substr($_SESSION['admin_nombre'], 0, 1)); ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?php echo htmlspecialchars($_SESSION['admin_nombre']); ?></a>
                </div>
            </div>

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                    <li class="nav-item">
                        <a href="<?php echo $base_url; ?>/admin/dashboard.php" class="nav-link">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="<?php echo $base_url; ?>/admin/crear_curso.php" class="nav-link">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="<?php echo $base_url; ?>/admin/ver_cursos.php" class="nav-link">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="<?php echo $base_url; ?>/admin/inscribir_participante.php" class="nav-link active">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="<?php echo $base_url; ?>/admin/ver_inscritos.php" class="nav-link">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="<?php echo $base_url; ?>/admin/logout.php" class="nav-link text-danger">
                            <i class="nav-icon fas fa-sign-out-alt"></i>
                            <p>Cerrar Sesión</p>
                        </a>
                    </li>
                </ul>
            </nav>
        </div>
    </aside>
    <?php endif; ?>

    <!-- Content Wrapper -->
    <div class="content-wrapper">
        <section class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1>Inscripción de Participante</h1>
                    </div>
                    <?php if ($es_admin): ?>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="<?php echo $base_url; ?>/admin/dashboard.php">Inicio</a></li>
                            <li class="breadcrumb-item"><a href="<?php echo $base_url; ?>/admin/ver_cursos.php">Cursos</a></li>
                            <li class="breadcrumb-item active">Inscribir Participante</li>
                        </ol>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        </section>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-md-12">
                        <div class="card card-primary">
                            <div class="card-header">
                                <h3 class="card-title">Complete los datos del participante</h3>
                            </div>
                            
                            <?php if ($error): ?>
                                <div class="alert alert-danger alert-dismissible ml-3 mr-3 mt-3">
                                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                                    <h5><i class="icon fas fa-ban"></i> Error!</h5>
                                    <?php echo htmlspecialchars($error); ?>
                                </div>
                            <?php endif; ?>
                            
                            <?php if ($success): ?>
                                <div class="alert alert-success alert-dismissible ml-3 mr-3 mt-3">
                                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                                    <h5><i class="icon fas fa-check"></i> Éxito!</h5>
                                    <?php echo htmlspecialchars($success); ?>
                                </div>
                            <?php endif; ?>

                            <form action="<?php echo $base_url; ?>/admin/inscribir_participante.php" method="POST" enctype="multipart/form-data" id="inscripcionForm">
                                <div class="card-body">
                                    <!-- Sección Curso -->
                                    <div class="form-section">
                                        <h4 class="section-title"><i class="fas fa-book-open mr-2"></i>Información del Curso</h4>
                                        <div class="form-group">
                                            <label for="curso_id">Curso:</label>
                                            <select id="curso_id" name="curso_id" class="form-control" required>
                                                <option value="">Seleccionar Curso</option>
                                                <?php foreach ($cursos as $curso): ?>
                                                  <option value="<?php echo htmlspecialchars($curso['id']); ?>"
    <?php echo (isset($_GET['curso_id']) && $_GET['curso_id'] == $curso['id']) ? 'selected' : ''; ?>>
    <?php echo htmlspecialchars($curso['nombre']); ?> - 
    Registro: <?php echo htmlspecialchars($curso['numero_registro']); ?> - 
    <?php 
    // Formatear fechas directamente desde PHP
    $fechaInicio = DateTime::createFromFormat('Y-m-d', $curso['fecha_inicio']);
    $fechaFin = DateTime::createFromFormat('Y-m-d', $curso['fecha_fin']);
    echo $fechaInicio->format('d/m/Y') . ' a ' . $fechaFin->format('d/m/Y'); 
    ?>
</option>
                                                <?php endforeach; ?>
                                            </select>
                                            <div id="cupos-container" class="cupos-container"></div>
                                        </div>
                                    </div>

                                    <!-- Sección para código de acceso (se muestra solo para cursos exclusivos) -->
                                    <div id="codigo_acceso_container" style="display: none;">
                                        <div class="form-group">
                                            <label for="codigo_acceso">Código de acceso</label>
                                            <input type="text" class="form-control" id="codigo_acceso" name="codigo_acceso" 
                                                   placeholder="Ingrese el código de acceso para este curso">
                                            <div class="file-info">Este curso es exclusivo, requiere código de acceso</div>
                                        </div>
                                    </div>

                                    <!-- Sección Información Personal -->
                                    <div class="form-section">
                                        <h4 class="section-title"><i class="fas fa-user mr-2"></i>Información Personal</h4>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="nombres">Nombres *</label>
                                                    <input type="text" name="nombres" id="nombres" class="form-control" placeholder="Ej: Juan Carlos" required
                                                        value="<?php echo isset($_POST['nombres']) ? htmlspecialchars($_POST['nombres']) : ''; ?>">
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="apellidos">Apellidos *</label>
                                                    <input type="text" name="apellidos" id="apellidos" class="form-control" placeholder="Ej: Pérez García" required
                                                        value="<?php echo isset($_POST['apellidos']) ? htmlspecialchars($_POST['apellidos']) : ''; ?>">
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="cedula">Número de identificación *</label>
                                                    <input type="text" name="cedula" id="cedula" class="form-control" placeholder="Ej: 1234567890" required
                                                        value="<?php echo isset($_POST['cedula']) ? htmlspecialchars($_POST['cedula']) : ''; ?>">
                                                    <div id="cedula-feedback" class="validation-message"></div>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="sexo">Sexo biológico *</label>
                                                    <select name="sexo" id="sexo" class="form-control" required>
                                                        <option value="">Seleccionar...</option>
                                                        <option value="Masculino" <?php echo (isset($_POST['sexo']) && $_POST['sexo'] == 'Masculino') ? 'selected' : ''; ?>>Masculino</option>
                                                        <option value="Femenino" <?php echo (isset($_POST['sexo']) && $_POST['sexo'] == 'Femenino') ? 'selected' : ''; ?>>Femenino</option>
                                                        <option value="Otro" <?php echo (isset($_POST['sexo']) && $_POST['sexo'] == 'Otro') ? 'selected' : ''; ?>>Otro</option>
                                                    </select>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="celular">Número de celular (WhatsApp) *</label>
                                                    <input type="tel" name="celular" id="celular" class="form-control" placeholder="Ej: 3101234567" required
                                                        value="<?php echo isset($_POST['celular']) ? htmlspecialchars($_POST['celular']) : ''; ?>">
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="correo">Correo electrónico *</label>
                                                    <input type="email" name="correo" id="correo" class="form-control" placeholder="Ej: ejemplo@dominio.com" required
                                                        value="<?php echo isset($_POST['correo']) ? htmlspecialchars($_POST['correo']) : ''; ?>">
                                                    <div id="correo-feedback" class="validation-message"></div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="form-group">
                                            <label for="direccion">Dirección de correspondencia *</label>
                                            <input type="text" name="direccion" id="direccion" class="form-control" placeholder="Ej: Calle 123 #45-67, Barrio la Aurora, Yopal Casanare" required
                                                value="<?php echo isset($_POST['direccion']) ? htmlspecialchars($_POST['direccion']) : ''; ?>">
                                        </div>
                                    </div>

                                    <!-- Sección Información Institucional -->
                                    <div class="form-section">
                                        <h4 class="section-title"><i class="fas fa-building mr-2"></i>Información Institucional</h4>
                                        <div class="row">
                                            <div class="col-md-4">
                                                <div class="form-group">
                                                    <label for="clase_cuerpo_bomberos">Clase de cuerpo de bomberos *</label>
                                                    <select name="clase_cuerpo_bomberos" id="clase_cuerpo_bomberos" class="form-control" required>
                                                        <option value="">Seleccionar...</option>
                                                        <option value="Voluntario" <?php echo (isset($_POST['clase_cuerpo_bomberos']) && $_POST['clase_cuerpo_bomberos'] == 'Voluntario') ? 'selected' : ''; ?>>Voluntario</option>
                                                        <option value="Oficial" <?php echo (isset($_POST['clase_cuerpo_bomberos']) && $_POST['clase_cuerpo_bomberos'] == 'Oficial') ? 'selected' : ''; ?>>Oficial</option>
                                                        <option value="Aeronautico" <?php echo (isset($_POST['clase_cuerpo_bomberos']) && $_POST['clase_cuerpo_bomberos'] == 'Aeronautico') ? 'selected' : ''; ?>>Aeronautico</option>
                                                    </select>
                                                </div>
                                            </div>
                                            <div class="col-md-4">
                                                <div class="form-group">
                                                    <label for="departamento">Departamento *</label>
                                                    <select name="departamento" id="departamento" class="form-control" required>
                                                        <option value="">Seleccionar departamento...</option>
                                                        <?php foreach ($departamentos as $depto => $municipios): ?>
                                                            <option value="<?php echo htmlspecialchars($depto); ?>"
                                                                <?php echo (isset($_POST['departamento']) && $_POST['departamento'] == $depto) ? 'selected' : ''; ?>>
                                                                <?php echo htmlspecialchars($depto); ?>
                                                            </option>
                                                        <?php endforeach; ?>
                                                    </select>
                                                </div>
                                            </div>
                                            <div class="col-md-4">
                                                <div class="form-group">
                                                    <label for="municipio">Cuerpo de Bomberos *</label>
                                                    <select name="municipio" id="municipio" class="form-control" required>
                                                        <option value="">Seleccionar municipio...</option>
                                                        <?php 
                                                        if (isset($_POST['departamento'])) {
                                                            $deptoSeleccionado = $_POST['departamento'];
                                                            if (array_key_exists($deptoSeleccionado, $departamentos)) {
                                                                foreach ($departamentos[$deptoSeleccionado] as $mun) {
                                                                    echo '<option value="' . htmlspecialchars($mun) . '"';
                                                                    if (isset($_POST['municipio']) && $_POST['municipio'] == $mun) {
                                                                        echo ' selected';
                                                                    }
                                                                    echo '>' . htmlspecialchars($mun) . '</option>';
                                                                }
                                                            }
                                                        }
                                                        ?>
                                                    </select>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <!-- Sección Documentos -->
                                    <div class="form-section">
                                        <h4 class="section-title"><i class="fas fa-file-alt mr-2"></i>Documentos Requeridos</h4>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="archivo_pdf_cedula">Fotocopia de cédula (PDF, JPG, PNG) *</label>
                                                    <input type="file" name="archivo_pdf_cedula" id="archivo_pdf_cedula" class="form-control file-upload" accept=".pdf,.jpg,.jpeg,.png" required>
                                                    <div class="file-info">Tamaño máximo: 2MB</div>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="archivo_img_fotografia">Fotografía del participante (JPG, PNG) *</label>
                                                    <input type="file" name="archivo_img_fotografia" id="archivo_img_fotografia" class="form-control file-upload" accept=".jpg,.jpeg,.png" required>
                                                    <div class="file-info">Tamaño máximo: 2MB - Se redimensionará a 300x300 píxeles</div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="archivo_pdf_comprobante_pago">Comprobante de pago (PDF, JPG, PNG) *</label>
                                                    <input type="file" name="archivo_pdf_comprobante_pago" id="archivo_pdf_comprobante_pago" class="form-control file-upload" accept=".pdf,.jpg,.jpeg,.png" required>
                                                    <div class="file-info">Tamaño máximo: 2MB</div>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="archivo_pdf_oficio_postulacion">Oficio de postulación (PDF, JPG, PNG) *</label>
                                                    <input type="file" name="archivo_pdf_oficio_postulacion" id="archivo_pdf_oficio_postulacion" class="form-control file-upload" accept=".pdf,.jpg,.jpeg,.png" required>
                                                    <div class="file-info">Tamaño máximo: 2MB</div>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="archivo_pdf_certificado_formacion">Certificado de formación de bombero (PDF, JPG, PNG) *</label>
                                                    <input type="file" name="archivo_pdf_certificado_formacion" id="archivo_pdf_certificado_formacion" class="form-control file-upload" accept=".pdf,.jpg,.jpeg,.png" required>
                                                    <div class="file-info">Tamaño máximo: 2MB</div>
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="archivo_pdf_rut">RUT (opcional, solo si requiere factura) (PDF, JPG, PNG)</label>
                                                    <input type="file" name="archivo_pdf_rut" id="archivo_pdf_rut" class="form-control file-upload" accept=".pdf,.jpg,.jpeg,.png">
                                                    <div class="file-info">Tamaño máximo: 2MB</div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>

                                <div class="card-footer">
                                    <button type="submit" id="submitBtn" class="btn btn-primary" <?php echo $cupos_agotados ? 'disabled' : ''; ?>>
                                        <i class="fas fa-save mr-2"></i>Registrar Participante
                                    </button>
                                    <?php if ($es_admin): ?>
                                    <a href="<?php echo $base_url; ?>/admin/ver_cursos.php" class="btn btn-default float-right">
                                        <i class="fas fa-times mr-2"></i>Cancelar
                                    </a>
                                    <?php else: ?>
                                    <a href="<?php echo $base_url; ?>/index.php" class="btn btn-default float-right">
                                        <i class="fas fa-times mr-2"></i>Cancelar
                                    </a>
                                    <?php endif; ?>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </div>

    <footer class="main-footer">
        <strong>Copyright &copy; <?php echo date('Y'); ?> <a href="<?php echo $base_url; ?>">ESIBOC</a>.</strong>
        Todos los derechos reservados.
        <div class="float-right d-none d-sm-inline-block">
            <b>Versión</b> 1.0.0
        </div>
    </footer>
</div>

<!-- REQUIRED SCRIPTS -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<script>
let cuposLlenos = false; // Variable global para controlar el estado de cupos

// Función mejorada para bloquear/desbloquear el formulario
function toggleForm(disabled, excludeFields = []) {
    const form = document.getElementById('inscripcionForm');
    const inputs = form.querySelectorAll('input:not(#curso_id), select, textarea, button');
    const submitBtn = document.getElementById('submitBtn');
    
    // Si los cupos están llenos, forzar el bloqueo
    if (cuposLlenos) {
        disabled = true;
    }
    
    inputs.forEach(input => {
        if (!excludeFields.includes(input.id)) {
            input.disabled = disabled;
        }
    });
    
    submitBtn.disabled = disabled;
    
    if (disabled) {
        form.classList.add('form-disabled');
        // Mostrar mensaje adicional si es por cupos llenos
        if (cuposLlenos) {
            const cuposContainer = document.getElementById("cupos-container");
            if (cuposContainer && !cuposContainer.querySelector('.cupos-llenos-message')) {
                const message = document.createElement('div');
                message.className = 'alert alert-danger cupos-llenos-message mt-2';
                message.innerHTML = '<i class="fas fa-ban mr-2"></i> EL CURSO ESTÁ LLENO - NO SE PERMITEN MÁS INSCRIPCIONES';
                cuposContainer.appendChild(message);
            }
        }
    } else {
        form.classList.remove('form-disabled');
    }
}

// Función para actualizar cupos periódicamente
function actualizarCuposPeriodicamente() {
    const cursoId = document.getElementById("curso_id").value;
    if (!cursoId) return;
    mostrarCuposDisponibles();
    setTimeout(actualizarCuposPeriodicamente, 5000);
}

// Función mejorada para mostrar cupos disponibles
function mostrarCuposDisponibles() {
    const cursoId = document.getElementById("curso_id").value;
    const cuposContainer = document.getElementById("cupos-container");
    
    if (!cursoId) {
        cuposContainer.innerHTML = '';
        toggleForm(false);
        cuposLlenos = false;
        return;
    }
    
    fetch(`<?php echo $base_url; ?>/admin/obtener_cupos.php?curso_id=${cursoId}&t=${new Date().getTime()}`)
        .then(response => {
            if (!response.ok) throw new Error('Error en la red');
            return response.json();
        })
        .then(data => {
            let cuposHTML = '';
            let alertClass = 'alert-info';
            let icon = 'fa-info-circle';
            let message = '';
            
            // Determinar estado de los cupos
            cuposLlenos = (data.estado === 'CUPO LLENO' || data.estado === 'FINALIZADO' || data.cupos_disponibles <= 0);
            
            if (cuposLlenos) {
                alertClass = 'alert-danger';
                icon = 'fa-exclamation-circle';
                message = 'CURSO LLENO - No hay cupos disponibles';
            } else if (data.estado === 'PRÓXIMO') {
                alertClass = 'alert-info';
                icon = 'fa-calendar-check';
                message = `CURSO PRÓXIMO A INICIAR - Cupos disponibles: ${data.cupos_disponibles}`;
            } else {
                alertClass = 'alert-success';
                icon = 'fa-check-circle';
                message = `Cupos disponibles: ${data.cupos_disponibles}`;
            }
            
            // Formatear fechas correctamente para Colombia (sin ajuste de zona horaria)
            const formatDate = (dateStr) => {
                if (!dateStr) return 'No disponible';
                const date = new Date(dateStr);
                // Ajustamos para Colombia (UTC-5)
                date.setMinutes(date.getMinutes() + date.getTimezoneOffset() + 300); // 300 minutos = 5 horas
                return date.toLocaleDateString('es-CO', {
                    day: '2-digit',
                    month: '2-digit',
                    year: 'numeric'
                });
            };
            
            const fechaInicio = formatDate(data.fecha_inicio);
            const fechaFin = formatDate(data.fecha_fin);
            
            const progressBar = `
                <div class="progress mt-2" style="height: 20px;">
                    <div class="progress-bar ${data.porcentaje_ocupado > 80 ? 'progress-bar-danger' : data.porcentaje_ocupado > 50 ? 'progress-bar-warning' : 'progress-bar-success'}" 
                         role="progressbar" 
                         style="width: ${data.porcentaje_ocupado}%" 
                         aria-valuenow="${data.porcentaje_ocupado}" 
                         aria-valuemin="0" 
                         aria-valuemax="100">
                        ${Math.round(data.porcentaje_ocupado)}%
                    </div>
                </div>
            `;
            
            cuposHTML = `
                <div class="alert ${alertClass}">
                    <i class="fas ${icon} mr-2"></i>
                    ${message}
                    <div class="mt-2">
                        <strong>Número de registro:</strong> ${data.numero_registro || 'No disponible'}
                    </div>
                    <div>
                        <strong>Fecha de inicio:</strong> ${fechaInicio}
                    </div>
                    <div class="mb-2">
                        <strong>Fecha de finalización:</strong> ${fechaFin}
                    </div>
                    <small class="d-block">Inscritos: ${data.inscritos}/${data.cupo_maximo}</small>
                    ${progressBar}
                    ${(data.cupos_disponibles > 0 && data.cupos_disponibles <= Math.max(3, data.cupo_maximo * 0.1)) ? 
                        '<div class="mt-2 text-danger font-weight-bold"><i class="fas fa-exclamation-triangle mr-1"></i> ÚLTIMOS CUPOS DISPONIBLES</div>' 
                        : (cuposLlenos ? 
                            '<div class="mt-2 text-danger font-weight-bold"><i class="fas fa-ban mr-1"></i> CUPOS LLENOS</div>' 
                            : '')}
                    <div class="text-muted">Actualizado: ${new Date().toLocaleTimeString()}</div>
                </div>
            `;
            
            cuposContainer.innerHTML = cuposHTML;
            toggleForm(cuposLlenos);
        })
        .catch(error => {
            cuposContainer.innerHTML = `
                <div class="alert alert-danger">
                    <i class="fas fa-exclamation-triangle mr-2"></i>
                    ${error.message || 'Error al obtener los cupos disponibles'}
                </div>`;
            console.error('Error:', error);
            cuposLlenos = false;
            toggleForm(false);
        });
}

// Función para verificar inscripción existente por Cédula
function verificarInscripcionExistente() {
    const cedula = document.getElementById("cedula").value;
    const cursoId = document.getElementById("curso_id").value;
    const cedulaFeedback = document.getElementById("cedula-feedback");
    
    if (cedula && cursoId) {
        fetch('<?php echo $base_url; ?>/admin/verificar_inscripcion.php?cedula=' + cedula + '&curso_id=' + cursoId)
            .then(response => response.json())
            .then(data => {
                if (data.inscrito) {
                    cedulaFeedback.innerHTML = '<i class="fas fa-exclamation-circle"></i> Esta Cédula ya está inscrita en este curso';
                    cedulaFeedback.className = 'validation-message invalid-feedback';
                    toggleForm(true);
                } else {
                    cedulaFeedback.innerHTML = '<i class="fas fa-check-circle"></i> Cédula válida para este curso';
                    cedulaFeedback.className = 'validation-message valid-feedback';
                    toggleForm(cuposLlenos);
                }
            })
            .catch(error => {
                console.error('Error:', error);
            });
    }
}

// Función para verificar correo existente en el curso
function verificarCorreoExistente() {
    const correo = document.getElementById("correo").value;
    const cursoId = document.getElementById("curso_id").value;
    const cedula = document.getElementById("cedula").value;
    const correoFeedback = document.getElementById("correo-feedback");
    const correoInput = document.getElementById("correo");
    
    if (correo && cursoId && cedula) {
        fetch('<?php echo $base_url; ?>/admin/verificar_correo.php?correo=' + encodeURIComponent(correo) + '&curso_id=' + cursoId + '&cedula=' + cedula)
            .then(response => response.json())
            .then(data => {
                if (data.existe) {
                    correoFeedback.innerHTML = '<i class="fas fa-exclamation-circle"></i> Este correo ya está registrado en este curso por otro participante';
                    correoFeedback.className = 'validation-message invalid-feedback';
                    correoInput.classList.add('correo-invalido');
                    correoInput.classList.remove('correo-valido');
                    toggleForm(true);
                } else {
                    correoFeedback.innerHTML = '<i class="fas fa-check-circle"></i> Correo disponible';
                    correoFeedback.className = 'validation-message valid-feedback';
                    correoInput.classList.add('correo-valido');
                    correoInput.classList.remove('correo-invalido');
                    toggleForm(cuposLlenos);
                }
            })
            .catch(error => {
                console.error('Error:', error);
            });
    }
}

// Función para actualizar municipios según departamento seleccionado
function actualizarMunicipios() {
    const departamento = document.getElementById("departamento").value;
    const municipioSelect = document.getElementById("municipio");
    
    municipioSelect.innerHTML = '<option value="">Seleccionar municipio...</option>';
    
    if (departamento) {
        fetch('<?php echo $base_url; ?>/admin/obtener_municipios.php?departamento=' + encodeURIComponent(departamento))
            .then(response => response.json())
            .then(municipios => {
                municipios.forEach(mun => {
                    const option = document.createElement('option');
                    option.value = mun;
                    option.textContent = mun;
                    municipioSelect.appendChild(option);
                });
            })
            .catch(error => {
                console.error('Error al obtener municipios:', error);
            });
    }
}

// Función para verificar si el curso es exclusivo y mostrar campo de código de acceso
function verificarCursoExclusivo() {
    const cursoId = document.getElementById('curso_id').value;
    if (!cursoId) {
        document.getElementById('codigo_acceso_container').style.display = 'none';
        return;
    }
    
    fetch(`<?php echo $base_url; ?>/admin/verificar_curso_exclusivo.php?curso_id=${cursoId}`)
        .then(response => response.json())
        .then(data => {
            const container = document.getElementById('codigo_acceso_container');
            const input = document.getElementById('codigo_acceso');
            
            if (data.es_exclusivo) {
                container.style.display = 'block';
                input.required = true;
            } else {
                container.style.display = 'none';
                input.required = false;
            }
        })
        .catch(error => {
            console.error('Error:', error);
        });
}

// Ejecutar al cargar la página
document.addEventListener('DOMContentLoaded', function() {
    <?php 
    if (isset($_GET['curso_id'])) {
        echo 'mostrarCuposDisponibles();';
        echo 'actualizarCuposPeriodicamente();';
    }
    ?>
    
    // Estilos CSS dinámicos para el formulario deshabilitado
    const style = document.createElement('style');
    style.textContent = `
        .form-disabled {
            opacity: 0.7;
            pointer-events: none;
            position: relative;
        }
        .form-disabled::after {
            content: "INSCRIPCIONES CERRADAS - CUPOS LLENOS";
            position: absolute;
            top: 0;
            left: 0;
            right: 0;
            bottom: 0;
            background: rgba(255, 0, 0, 0.1);
            display: flex;
            align-items: center;
            justify-content: center;
            color: #d9534f;
            font-weight: bold;
            font-size: 1.5em;
            z-index: 1000;
        }
        .correo-invalido {
            border-color: #dc3545;
        }
        .correo-valido {
            border-color: #28a745;
        }
    `;
    document.head.appendChild(style);
    
    // Event listeners
    document.getElementById('cedula').addEventListener('input', function() {
        if (document.getElementById('curso_id').value) {
            verificarInscripcionExistente();
            if (document.getElementById('correo').value) {
                verificarCorreoExistente();
            }
        }
    });
    
    document.getElementById('correo').addEventListener('input', function() {
        if (document.getElementById('curso_id').value && document.getElementById('cedula').value) {
            verificarCorreoExistente();
        }
    });
    
    document.getElementById('curso_id').addEventListener('change', function() {
        mostrarCuposDisponibles();
        actualizarCuposPeriodicamente();
        verificarCursoExclusivo();
        if (document.getElementById('cedula').value) {
            verificarInscripcionExistente();
        }
        if (document.getElementById('correo').value) {
            verificarCorreoExistente();
        }
    });
    
    document.getElementById('departamento').addEventListener('change', function() {
        actualizarMunicipios();
    });
    
    document.getElementById('inscripcionForm').addEventListener('submit', function(e) {
        // Verificar primero si los cupos están llenos
        if (cuposLlenos) {
            e.preventDefault();
            alert('No se pueden aceptar más inscripciones porque el curso está lleno.');
            return;
        }
        
        const correoFeedback = document.getElementById('correo-feedback');
        if (correoFeedback.classList.contains('invalid-feedback')) {
            e.preventDefault();
            alert('Por favor corrige el problema con el correo electrónico antes de enviar el formulario.');
            return;
        }
        
        const cedula = document.getElementById('cedula').value;
        if (!/^\d+$/.test(cedula)) {
            alert('El número de identificación debe contener solo dígitos');
            e.preventDefault();
            return;
        }
        
        const celular = document.getElementById('celular').value;
        if (!/^\d{10,15}$/.test(celular)) {
            alert('El número de celular debe contener entre 10 y 15 dígitos');
            e.preventDefault();
            return;
        }
        
        const requiredFiles = [
            'archivo_pdf_cedula',
            'archivo_img_fotografia',
            'archivo_pdf_comprobante_pago',
            'archivo_pdf_oficio_postulacion',
            'archivo_pdf_certificado_formacion'
        ];
        
        for (const fileId of requiredFiles) {
            const fileInput = document.getElementById(fileId);
            if (fileInput.files.length === 0) {
                alert('El archivo ' + fileId.replace(/_/g, ' ') + ' es requerido');
                e.preventDefault();
                return;
            }
            
            if (fileInput.files[0].size > 2 * 1024 * 1024) {
                alert('El archivo ' + fileId.replace(/_/g, ' ') + ' excede el tamaño máximo de 2MB');
                e.preventDefault();
                return;
            }
        }

        // Verificar si el curso es exclusivo y si se proporcionó el código de acceso
        const codigoAccesoContainer = document.getElementById('codigo_acceso_container');
        if (codigoAccesoContainer.style.display !== 'none') {
            const codigoAcceso = document.getElementById('codigo_acceso').value;
            if (!codigoAcceso) {
                alert('Este curso es exclusivo y requiere un código de acceso.');
                e.preventDefault();
                return;
            }
        }
    });

    // Verificar curso exclusivo al cargar si hay un curso seleccionado
    if (document.getElementById('curso_id').value) {
        verificarCursoExclusivo();
    }
});
</script>

</body>
</html>