<?php
header('Content-Type: application/json');
ini_set('display_errors', 0);
error_reporting(0);

require_once __DIR__ . '/../config/database.php';

// Configurar zona horaria de Colombia
date_default_timezone_set('America/Bogota');

if (!isset($_GET['curso_id'])) {
    echo json_encode(['error' => 'ID de curso no proporcionado']);
    exit;
}

$curso_id = intval($_GET['curso_id']);

try {
    $pdo->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);

    $stmt = $pdo->prepare("
        SELECT 
            c.id,
            c.nombre,
            c.numero_registro,  -- Asegurando que incluimos este campo
            c.cupo_maximo,
            c.fecha_inicio,
            c.fecha_fin,
            c.habilitado,
            (SELECT COUNT(*) FROM inscripciones WHERE curso_id = c.id) AS inscritos,
            GREATEST(0, c.cupo_maximo - (SELECT COUNT(*) FROM inscripciones WHERE curso_id = c.id)) AS cupos_disponibles,
            c.estado
        FROM cursos c
        WHERE c.id = ?
        LIMIT 1
    ");
    $stmt->execute([$curso_id]);
    $curso = $stmt->fetch();

    if (!$curso || !is_array($curso)) {
        echo json_encode(['error' => 'Curso no encontrado']);
        exit;
    }

    // Calcular porcentaje ocupado
    $cupo_maximo = (int)$curso['cupo_maximo'];
    $inscritos = (int)$curso['inscritos'];
    $cupos_disponibles = (int)$curso['cupos_disponibles'];
    $porcentaje_ocupado = ($cupo_maximo > 0) ? ($inscritos / $cupo_maximo) * 100 : 0;
    $porcentaje_ocupado = round($porcentaje_ocupado, 2);

    // Determinar estado del curso
    $fecha_actual = date('Y-m-d');
    $estado_curso = $curso['estado'];
    
    if ($curso['estado'] == 'activo') {
        if (strtotime($curso['fecha_inicio']) > strtotime($fecha_actual)) {
            $estado_curso = 'PRÓXIMO';
        } elseif (strtotime($curso['fecha_fin']) < strtotime($fecha_actual)) {
            $estado_curso = 'FINALIZADO';
        } elseif ($cupos_disponibles <= 0) {
            $estado_curso = 'CUPO LLENO';
        } else {
            $estado_curso = 'DISPONIBLE';
        }
    }

    // Preparar respuesta
    $response = [
        'id' => $curso['id'],
        'nombre' => $curso['nombre'],
        'numero_registro' => $curso['numero_registro'] ?? 'No disponible', // Asegurar que siempre haya un valor
        'cupo_maximo' => $cupo_maximo,
        'inscritos' => $inscritos,
        'cupos_disponibles' => $cupos_disponibles,
        'porcentaje_ocupado' => $porcentaje_ocupado,
        'fecha_inicio' => $curso['fecha_inicio'],
        'fecha_fin' => $curso['fecha_fin'],
        'habilitado' => (bool)$curso['habilitado'],
        'estado' => $estado_curso,
        'status' => 'success'
    ];

    echo json_encode($response);
    exit;

} catch (Exception $e) {
    // Para depuración, puedes descomentar la siguiente línea
    // error_log("Error en obtener_cupos.php: " . $e->getMessage());
    echo json_encode(['error' => 'Error de base de datos']);
    exit;
}
