<?php
require_once __DIR__ . '/../config/database.php';

header('Content-Type: application/json');

if (!isset($_GET['correo']) || !isset($_GET['curso_id']) || !isset($_GET['cedula'])) {
    echo json_encode(['error' => 'Datos insuficientes']);
    exit;
}

$correo = filter_input(INPUT_GET, 'correo', FILTER_SANITIZE_EMAIL);
$curso_id = filter_input(INPUT_GET, 'curso_id', FILTER_VALIDATE_INT);
$cedula = filter_input(INPUT_GET, 'cedula', FILTER_SANITIZE_STRING);

if (!$correo || !$curso_id || !$cedula) {
    echo json_encode(['error' => 'Datos inválidos']);
    exit;
}

try {
    $stmt = $pdo->prepare("SELECT COUNT(*) as existe FROM participantes p 
                          JOIN inscripciones i ON p.id = i.participante_id 
                          WHERE p.correo = ? AND i.curso_id = ? AND p.cedula != ?");
    $stmt->execute([$correo, $curso_id, $cedula]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    
    echo json_encode([
        'existe' => (int)$result['existe'] > 0
    ]);
} catch (PDOException $e) {
    echo json_encode(['error' => 'Error en la base de datos: ' . $e->getMessage()]);
}