<?php
require_once __DIR__ . '/../config/database.php';

header('Content-Type: application/json');

if (!isset($_GET['cedula']) || !isset($_GET['curso_id'])) {
    echo json_encode(['error' => 'Datos insuficientes']);
    exit;
}

$cedula = filter_input(INPUT_GET, 'cedula', FILTER_SANITIZE_STRING);
$curso_id = filter_input(INPUT_GET, 'curso_id', FILTER_VALIDATE_INT);

if (!$cedula || !$curso_id) {
    echo json_encode(['error' => 'Datos inválidos']);
    exit;
}

try {
    $stmt = $pdo->prepare("SELECT COUNT(*) as inscrito FROM participantes p 
                          JOIN inscripciones i ON p.id = i.participante_id 
                          WHERE p.cedula = ? AND i.curso_id = ?");
    $stmt->execute([$cedula, $curso_id]);
    $result = $stmt->fetch(PDO::FETCH_ASSOC);
    
    echo json_encode([
        'inscrito' => (int)$result['inscrito'] > 0
    ]);
} catch (PDOException $e) {
    echo json_encode(['error' => 'Error en la base de datos: ' . $e->getMessage()]);
}