<?php
session_start();
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    exit;
}

require_once '../config/database.php';

// Obtener los cursos disponibles
$stmt = $pdo->query("SELECT * FROM cursos WHERE estado = 'activo' ORDER BY fecha_inicio DESC");
$cursos = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Manejar el formulario de inscripción
$error = '';
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $nombre = $_POST['nombre'];
    $cedula = $_POST['cedula'];
    $correo = $_POST['correo'];
    $telefono = $_POST['telefono'];
    $institucion = $_POST['institucion'];
    $cargo = $_POST['cargo'];
    $curso_id = $_POST['curso_id'];

    // Verificar si el participante ya está inscrito en este curso
    $stmt = $pdo->prepare("SELECT COUNT(*) FROM inscripciones WHERE participante_id = (SELECT id FROM participantes WHERE cedula = ?) AND curso_id = ?");
    $stmt->execute([$cedula, $curso_id]);
    $inscripcion_existente = $stmt->fetchColumn();

    if ($inscripcion_existente > 0) {
        $error = "Ya estás inscrito en este curso.";
    } else {
        // Verificar si el participante ya existe en la base de datos
        $stmt = $pdo->prepare("SELECT id FROM participantes WHERE cedula = ?");
        $stmt->execute([$cedula]);
        $participante_id = $stmt->fetchColumn();

        // Si el participante no existe, insertarlo
        if (!$participante_id) {
            $stmt = $pdo->prepare("INSERT INTO participantes (nombre, cedula, correo, telefono, institucion, cargo) VALUES (?, ?, ?, ?, ?, ?)");
            $stmt->execute([$nombre, $cedula, $correo, $telefono, $institucion, $cargo]);
            $participante_id = $pdo->lastInsertId();
        }

        // Inscribir al participante en el curso
        $stmt = $pdo->prepare("INSERT INTO inscripciones (participante_id, curso_id) VALUES (?, ?)");
        $stmt->execute([$participante_id, $curso_id]);

        header("Location: ver_inscritos.php"); // Redirigir a la página de inscripciones
        exit;
    }
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Inscribir Participante | ESIBOC</title>
    <link rel="stylesheet" href="../assets/css/styles.css">
</head>
<body>
    <div class="dashboard-container">
        <div class="dashboard-card">
            <h1>Inscripción de Participante</h1>
            <?php if ($error): ?>
                <div class="error"><?php echo $error; ?></div>
            <?php endif; ?>

            <form action="inscribir_participante.php" method="POST">
                <div class="form-group">
                    <label for="nombre">Nombre del Participante</label>
                    <input type="text" name="nombre" id="nombre" placeholder="Nombre completo" required>
                </div>

                <div class="form-group">
                    <label for="cedula">Cédula</label>
                    <input type="text" name="cedula" id="cedula" placeholder="Número de cédula" required>
                </div>

                <div class="form-group">
                    <label for="correo">Correo Electrónico</label>
                    <input type="email" name="correo" id="correo" placeholder="Correo electrónico" required>
                </div>

                <div class="form-group">
                    <label for="telefono">Teléfono</label>
                    <input type="text" name="telefono" id="telefono" placeholder="Teléfono de contacto" required>
                </div>

                <div class="form-group">
                    <label for="institucion">Institución</label>
                    <input type="text" name="institucion" id="institucion" placeholder="Nombre de la institución" required>
                </div>

                <div class="form-group">
                    <label for="cargo">Cargo</label>
                    <input type="text" name="cargo" id="cargo" placeholder="Cargo en la institución" required>
                </div>

                <div class="form-group">
                    <label for="curso_id">Curso</label>
                    <select name="curso_id" id="curso_id" required>
                        <option value="">Seleccionar curso</option>
                        <?php foreach ($cursos as $curso): ?>
                            <option value="<?= $curso['id'] ?>"><?= htmlspecialchars($curso['nombre']) ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <button type="submit">Inscribir</button>
            </form>

            <a href="ver_inscritos.php" class="back-link">← Volver a Inscripciones</a>
        </div>
    </div>
</body>
</html>
