<?php
session_start();
require_once '../config/database.php';

// Verificar si es administrador
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    exit;
}

// Obtener todos los cursos con participantes
$query = "SELECT c.id, c.nombre AS nombre_curso, 
          p.nombres, p.apellidos, p.cedula, p.correo, 
          p.clase_cuerpo_bomberos, p.municipio, p.direccion,
          p.archivo_img_fotografia
          FROM cursos c
          JOIN inscripciones i ON c.id = i.curso_id
          JOIN participantes p ON i.participante_id = p.id
          ORDER BY c.nombre, p.apellidos, p.nombres";

$stmt = $pdo->query($query);
$participantes = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Agrupar por curso
$cursos = [];
foreach ($participantes as $participante) {
    $cursoId = $participante['id'];
    if (!isset($cursos[$cursoId])) {
        $cursos[$cursoId] = [
            'nombre' => $participante['nombre_curso'],
            'participantes' => []
        ];
    }
    $cursos[$cursoId]['participantes'][] = $participante;
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Directorio de Participantes | ESIBOC</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css">
    <style>
        body {
            background-color: #f8f9fa;
            padding: 20px;
        }
        .curso-header {
            background-color: #007bff;
            color: white;
            padding: 15px;
            border-radius: 5px;
            margin-bottom: 20px;
        }
        .participante-card {
            border: 1px solid #dee2e6;
            border-radius: 5px;
            padding: 15px;
            margin-bottom: 20px;
            background-color: white;
            box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        }
        .participante-foto {
            width: 100px;
            height: 100px;
            border-radius: 50%;
            object-fit: cover;
            border: 3px solid #007bff;
        }
        .participante-info {
            margin-left: 20px;
        }
        .sigla-cb {
            font-weight: bold;
            color: #dc3545;
        }
        .separador {
            height: 2px;
            background-color: #e9ecef;
            margin: 20px 0;
        }
        .foto-placeholder {
            width: 100px;
            height: 100px;
            border-radius: 50%;
            background-color: #6c757d;
            display: flex;
            align-items: center;
            justify-content: center;
            color: white;
            border: 3px solid #007bff;
        }
    </style>
</head>
<body>
    <div class="container">
        <h1 class="text-center mb-4">Directorio de Participantes</h1>
        
        <?php foreach ($cursos as $cursoId => $curso): ?>
            <div class="curso-header">
                <h2><?= htmlspecialchars($curso['nombre']) ?></h2>
            </div>
            
            <div class="row">
                <?php 
                $contador = 0;
                foreach ($curso['participantes'] as $participante): 
                    $contador++;
                ?>
                    <div class="col-md-6">
                        <div class="participante-card d-flex">
                            <!-- Foto del participante -->
                            <div>
                                <?php 
                                $rutaFoto = '../' . $participante['archivo_img_fotografia'];
                                if (!empty($participante['archivo_img_fotografia']) && file_exists($rutaFoto)): 
                                ?>
                                    <img src="<?= $rutaFoto ?>" 
                                         class="participante-foto" 
                                         alt="Foto de <?= htmlspecialchars($participante['nombres']) ?>">
                                <?php else: ?>
                                    <div class="foto-placeholder">
                                        <i class="fas fa-user fa-3x"></i>
                                    </div>
                                <?php endif; ?>
                            </div>
                            
                            <!-- Información del participante -->
                            <div class="participante-info">
                                <h3><?= htmlspecialchars($participante['nombres'] . ' ' . $participante['apellidos']) ?></h3>
                                <p><strong>Cédula:</strong> <?= htmlspecialchars($participante['cedula']) ?></p>
                                <p><strong>Correo:</strong> <?= htmlspecialchars($participante['correo']) ?></p>
                                <p>
                                    <strong>Municipio:</strong> 
                                    <span class="sigla-cb">CB<?= substr($participante['clase_cuerpo_bomberos'], 0, 1) ?></span>
                                    <?= htmlspecialchars($participante['municipio']) ?>
                                </p>
                                <p><strong>Dirección:</strong> <?= htmlspecialchars($participante['direccion']) ?></p>
                            </div>
                        </div>
                    </div>
                    
                    <!-- Separador entre filas -->
                    <?php if ($contador % 2 == 0): ?>
                        <div class="w-100"></div>
                    <?php endif; ?>
                    
                    <!-- Separador entre participantes -->
                    <div class="col-12">
                        <div class="separador"></div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endforeach; ?>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>